# coding: utf-8
# Copyright (c) 2016, 2020, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class CreateLogAnalyticsObjectCollectionRuleDetails(object):
    """
    The configuration details of an Object Storage based collection rule to enable automatic log collection.
    """

    #: A constant which can be used with the collection_type property of a CreateLogAnalyticsObjectCollectionRuleDetails.
    #: This constant has a value of "LIVE"
    COLLECTION_TYPE_LIVE = "LIVE"

    #: A constant which can be used with the collection_type property of a CreateLogAnalyticsObjectCollectionRuleDetails.
    #: This constant has a value of "HISTORIC"
    COLLECTION_TYPE_HISTORIC = "HISTORIC"

    #: A constant which can be used with the collection_type property of a CreateLogAnalyticsObjectCollectionRuleDetails.
    #: This constant has a value of "HISTORIC_LIVE"
    COLLECTION_TYPE_HISTORIC_LIVE = "HISTORIC_LIVE"

    def __init__(self, **kwargs):
        """
        Initializes a new CreateLogAnalyticsObjectCollectionRuleDetails object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param name:
            The value to assign to the name property of this CreateLogAnalyticsObjectCollectionRuleDetails.
        :type name: str

        :param description:
            The value to assign to the description property of this CreateLogAnalyticsObjectCollectionRuleDetails.
        :type description: str

        :param compartment_id:
            The value to assign to the compartment_id property of this CreateLogAnalyticsObjectCollectionRuleDetails.
        :type compartment_id: str

        :param os_namespace:
            The value to assign to the os_namespace property of this CreateLogAnalyticsObjectCollectionRuleDetails.
        :type os_namespace: str

        :param os_bucket_name:
            The value to assign to the os_bucket_name property of this CreateLogAnalyticsObjectCollectionRuleDetails.
        :type os_bucket_name: str

        :param collection_type:
            The value to assign to the collection_type property of this CreateLogAnalyticsObjectCollectionRuleDetails.
            Allowed values for this property are: "LIVE", "HISTORIC", "HISTORIC_LIVE"
        :type collection_type: str

        :param poll_since:
            The value to assign to the poll_since property of this CreateLogAnalyticsObjectCollectionRuleDetails.
        :type poll_since: str

        :param poll_till:
            The value to assign to the poll_till property of this CreateLogAnalyticsObjectCollectionRuleDetails.
        :type poll_till: str

        :param log_group_id:
            The value to assign to the log_group_id property of this CreateLogAnalyticsObjectCollectionRuleDetails.
        :type log_group_id: str

        :param log_source_name:
            The value to assign to the log_source_name property of this CreateLogAnalyticsObjectCollectionRuleDetails.
        :type log_source_name: str

        :param entity_id:
            The value to assign to the entity_id property of this CreateLogAnalyticsObjectCollectionRuleDetails.
        :type entity_id: str

        :param char_encoding:
            The value to assign to the char_encoding property of this CreateLogAnalyticsObjectCollectionRuleDetails.
        :type char_encoding: str

        :param overrides:
            The value to assign to the overrides property of this CreateLogAnalyticsObjectCollectionRuleDetails.
        :type overrides: dict(str, list[PropertyOverride])

        :param defined_tags:
            The value to assign to the defined_tags property of this CreateLogAnalyticsObjectCollectionRuleDetails.
        :type defined_tags: dict(str, dict(str, object))

        :param freeform_tags:
            The value to assign to the freeform_tags property of this CreateLogAnalyticsObjectCollectionRuleDetails.
        :type freeform_tags: dict(str, str)

        """
        self.swagger_types = {
            'name': 'str',
            'description': 'str',
            'compartment_id': 'str',
            'os_namespace': 'str',
            'os_bucket_name': 'str',
            'collection_type': 'str',
            'poll_since': 'str',
            'poll_till': 'str',
            'log_group_id': 'str',
            'log_source_name': 'str',
            'entity_id': 'str',
            'char_encoding': 'str',
            'overrides': 'dict(str, list[PropertyOverride])',
            'defined_tags': 'dict(str, dict(str, object))',
            'freeform_tags': 'dict(str, str)'
        }

        self.attribute_map = {
            'name': 'name',
            'description': 'description',
            'compartment_id': 'compartmentId',
            'os_namespace': 'osNamespace',
            'os_bucket_name': 'osBucketName',
            'collection_type': 'collectionType',
            'poll_since': 'pollSince',
            'poll_till': 'pollTill',
            'log_group_id': 'logGroupId',
            'log_source_name': 'logSourceName',
            'entity_id': 'entityId',
            'char_encoding': 'charEncoding',
            'overrides': 'overrides',
            'defined_tags': 'definedTags',
            'freeform_tags': 'freeformTags'
        }

        self._name = None
        self._description = None
        self._compartment_id = None
        self._os_namespace = None
        self._os_bucket_name = None
        self._collection_type = None
        self._poll_since = None
        self._poll_till = None
        self._log_group_id = None
        self._log_source_name = None
        self._entity_id = None
        self._char_encoding = None
        self._overrides = None
        self._defined_tags = None
        self._freeform_tags = None

    @property
    def name(self):
        """
        **[Required]** Gets the name of this CreateLogAnalyticsObjectCollectionRuleDetails.
        A unique name given to the rule. The name must be unique within the tenancy, and cannot be modified.


        :return: The name of this CreateLogAnalyticsObjectCollectionRuleDetails.
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """
        Sets the name of this CreateLogAnalyticsObjectCollectionRuleDetails.
        A unique name given to the rule. The name must be unique within the tenancy, and cannot be modified.


        :param name: The name of this CreateLogAnalyticsObjectCollectionRuleDetails.
        :type: str
        """
        self._name = name

    @property
    def description(self):
        """
        Gets the description of this CreateLogAnalyticsObjectCollectionRuleDetails.
        A string that describes the details of the rule. It does not have to be unique, and can be changed.
        Avoid entering confidential information.


        :return: The description of this CreateLogAnalyticsObjectCollectionRuleDetails.
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """
        Sets the description of this CreateLogAnalyticsObjectCollectionRuleDetails.
        A string that describes the details of the rule. It does not have to be unique, and can be changed.
        Avoid entering confidential information.


        :param description: The description of this CreateLogAnalyticsObjectCollectionRuleDetails.
        :type: str
        """
        self._description = description

    @property
    def compartment_id(self):
        """
        **[Required]** Gets the compartment_id of this CreateLogAnalyticsObjectCollectionRuleDetails.
        The `OCID`__ of the compartment to which this rule belongs.

        __ https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm


        :return: The compartment_id of this CreateLogAnalyticsObjectCollectionRuleDetails.
        :rtype: str
        """
        return self._compartment_id

    @compartment_id.setter
    def compartment_id(self, compartment_id):
        """
        Sets the compartment_id of this CreateLogAnalyticsObjectCollectionRuleDetails.
        The `OCID`__ of the compartment to which this rule belongs.

        __ https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm


        :param compartment_id: The compartment_id of this CreateLogAnalyticsObjectCollectionRuleDetails.
        :type: str
        """
        self._compartment_id = compartment_id

    @property
    def os_namespace(self):
        """
        **[Required]** Gets the os_namespace of this CreateLogAnalyticsObjectCollectionRuleDetails.
        Object Storage namespace.


        :return: The os_namespace of this CreateLogAnalyticsObjectCollectionRuleDetails.
        :rtype: str
        """
        return self._os_namespace

    @os_namespace.setter
    def os_namespace(self, os_namespace):
        """
        Sets the os_namespace of this CreateLogAnalyticsObjectCollectionRuleDetails.
        Object Storage namespace.


        :param os_namespace: The os_namespace of this CreateLogAnalyticsObjectCollectionRuleDetails.
        :type: str
        """
        self._os_namespace = os_namespace

    @property
    def os_bucket_name(self):
        """
        **[Required]** Gets the os_bucket_name of this CreateLogAnalyticsObjectCollectionRuleDetails.
        Name of the Object Storage bucket.


        :return: The os_bucket_name of this CreateLogAnalyticsObjectCollectionRuleDetails.
        :rtype: str
        """
        return self._os_bucket_name

    @os_bucket_name.setter
    def os_bucket_name(self, os_bucket_name):
        """
        Sets the os_bucket_name of this CreateLogAnalyticsObjectCollectionRuleDetails.
        Name of the Object Storage bucket.


        :param os_bucket_name: The os_bucket_name of this CreateLogAnalyticsObjectCollectionRuleDetails.
        :type: str
        """
        self._os_bucket_name = os_bucket_name

    @property
    def collection_type(self):
        """
        Gets the collection_type of this CreateLogAnalyticsObjectCollectionRuleDetails.
        The type of collection.
        Accepted values are: LIVE.
        Collection type LIVE indicates to enable log collection from the time of this rule creation,
        and continue until the rule exists.

        Allowed values for this property are: "LIVE", "HISTORIC", "HISTORIC_LIVE"


        :return: The collection_type of this CreateLogAnalyticsObjectCollectionRuleDetails.
        :rtype: str
        """
        return self._collection_type

    @collection_type.setter
    def collection_type(self, collection_type):
        """
        Sets the collection_type of this CreateLogAnalyticsObjectCollectionRuleDetails.
        The type of collection.
        Accepted values are: LIVE.
        Collection type LIVE indicates to enable log collection from the time of this rule creation,
        and continue until the rule exists.


        :param collection_type: The collection_type of this CreateLogAnalyticsObjectCollectionRuleDetails.
        :type: str
        """
        allowed_values = ["LIVE", "HISTORIC", "HISTORIC_LIVE"]
        if not value_allowed_none_or_none_sentinel(collection_type, allowed_values):
            raise ValueError(
                "Invalid value for `collection_type`, must be None or one of {0}"
                .format(allowed_values)
            )
        self._collection_type = collection_type

    @property
    def poll_since(self):
        """
        Gets the poll_since of this CreateLogAnalyticsObjectCollectionRuleDetails.
        The oldest time of the file in the bucket to consider for collection.
        Accepted values are: BEGINNING or CURRENT_TIME or RFC3339 formatted datetime string.
        When collectionType is LIVE, specifying pollSince value other than CURRENT_TIME will result in error.


        :return: The poll_since of this CreateLogAnalyticsObjectCollectionRuleDetails.
        :rtype: str
        """
        return self._poll_since

    @poll_since.setter
    def poll_since(self, poll_since):
        """
        Sets the poll_since of this CreateLogAnalyticsObjectCollectionRuleDetails.
        The oldest time of the file in the bucket to consider for collection.
        Accepted values are: BEGINNING or CURRENT_TIME or RFC3339 formatted datetime string.
        When collectionType is LIVE, specifying pollSince value other than CURRENT_TIME will result in error.


        :param poll_since: The poll_since of this CreateLogAnalyticsObjectCollectionRuleDetails.
        :type: str
        """
        self._poll_since = poll_since

    @property
    def poll_till(self):
        """
        Gets the poll_till of this CreateLogAnalyticsObjectCollectionRuleDetails.
        The oldest time of the file in the bucket to consider for collection.
        Accepted values are: CURRENT_TIME or RFC3339 formatted datetime string.
        When collectionType is LIVE, specifying pollTill will result in error.


        :return: The poll_till of this CreateLogAnalyticsObjectCollectionRuleDetails.
        :rtype: str
        """
        return self._poll_till

    @poll_till.setter
    def poll_till(self, poll_till):
        """
        Sets the poll_till of this CreateLogAnalyticsObjectCollectionRuleDetails.
        The oldest time of the file in the bucket to consider for collection.
        Accepted values are: CURRENT_TIME or RFC3339 formatted datetime string.
        When collectionType is LIVE, specifying pollTill will result in error.


        :param poll_till: The poll_till of this CreateLogAnalyticsObjectCollectionRuleDetails.
        :type: str
        """
        self._poll_till = poll_till

    @property
    def log_group_id(self):
        """
        **[Required]** Gets the log_group_id of this CreateLogAnalyticsObjectCollectionRuleDetails.
        Log Analytics Log group OCID to associate the processed logs with.


        :return: The log_group_id of this CreateLogAnalyticsObjectCollectionRuleDetails.
        :rtype: str
        """
        return self._log_group_id

    @log_group_id.setter
    def log_group_id(self, log_group_id):
        """
        Sets the log_group_id of this CreateLogAnalyticsObjectCollectionRuleDetails.
        Log Analytics Log group OCID to associate the processed logs with.


        :param log_group_id: The log_group_id of this CreateLogAnalyticsObjectCollectionRuleDetails.
        :type: str
        """
        self._log_group_id = log_group_id

    @property
    def log_source_name(self):
        """
        **[Required]** Gets the log_source_name of this CreateLogAnalyticsObjectCollectionRuleDetails.
        Name of the Log Analytics Source to use for the processing.


        :return: The log_source_name of this CreateLogAnalyticsObjectCollectionRuleDetails.
        :rtype: str
        """
        return self._log_source_name

    @log_source_name.setter
    def log_source_name(self, log_source_name):
        """
        Sets the log_source_name of this CreateLogAnalyticsObjectCollectionRuleDetails.
        Name of the Log Analytics Source to use for the processing.


        :param log_source_name: The log_source_name of this CreateLogAnalyticsObjectCollectionRuleDetails.
        :type: str
        """
        self._log_source_name = log_source_name

    @property
    def entity_id(self):
        """
        Gets the entity_id of this CreateLogAnalyticsObjectCollectionRuleDetails.
        Log Analytics entity OCID. Associates the processed logs with the given entity (optional).


        :return: The entity_id of this CreateLogAnalyticsObjectCollectionRuleDetails.
        :rtype: str
        """
        return self._entity_id

    @entity_id.setter
    def entity_id(self, entity_id):
        """
        Sets the entity_id of this CreateLogAnalyticsObjectCollectionRuleDetails.
        Log Analytics entity OCID. Associates the processed logs with the given entity (optional).


        :param entity_id: The entity_id of this CreateLogAnalyticsObjectCollectionRuleDetails.
        :type: str
        """
        self._entity_id = entity_id

    @property
    def char_encoding(self):
        """
        Gets the char_encoding of this CreateLogAnalyticsObjectCollectionRuleDetails.
        An optional character encoding to aid in detecting the character encoding of the contents of the objects while processing.
        It is recommended to set this value as ISO_8589_1 when configuring content of the objects having more numeric characters,
        and very few alphabets.
        For e.g. this applies when configuring VCN Flow Logs.


        :return: The char_encoding of this CreateLogAnalyticsObjectCollectionRuleDetails.
        :rtype: str
        """
        return self._char_encoding

    @char_encoding.setter
    def char_encoding(self, char_encoding):
        """
        Sets the char_encoding of this CreateLogAnalyticsObjectCollectionRuleDetails.
        An optional character encoding to aid in detecting the character encoding of the contents of the objects while processing.
        It is recommended to set this value as ISO_8589_1 when configuring content of the objects having more numeric characters,
        and very few alphabets.
        For e.g. this applies when configuring VCN Flow Logs.


        :param char_encoding: The char_encoding of this CreateLogAnalyticsObjectCollectionRuleDetails.
        :type: str
        """
        self._char_encoding = char_encoding

    @property
    def overrides(self):
        """
        Gets the overrides of this CreateLogAnalyticsObjectCollectionRuleDetails.
        The override is used to modify some important configuration properties for objects matching a specific pattern inside the bucket.
        Supported propeties for override are - logSourceName, charEncoding.
        Supported matchType for override are \"contains\".


        :return: The overrides of this CreateLogAnalyticsObjectCollectionRuleDetails.
        :rtype: dict(str, list[PropertyOverride])
        """
        return self._overrides

    @overrides.setter
    def overrides(self, overrides):
        """
        Sets the overrides of this CreateLogAnalyticsObjectCollectionRuleDetails.
        The override is used to modify some important configuration properties for objects matching a specific pattern inside the bucket.
        Supported propeties for override are - logSourceName, charEncoding.
        Supported matchType for override are \"contains\".


        :param overrides: The overrides of this CreateLogAnalyticsObjectCollectionRuleDetails.
        :type: dict(str, list[PropertyOverride])
        """
        self._overrides = overrides

    @property
    def defined_tags(self):
        """
        Gets the defined_tags of this CreateLogAnalyticsObjectCollectionRuleDetails.
        Defined tags for this resource. Each key is predefined and scoped to a namespace.
        Example: `{\"foo-namespace\": {\"bar-key\": \"value\"}}`


        :return: The defined_tags of this CreateLogAnalyticsObjectCollectionRuleDetails.
        :rtype: dict(str, dict(str, object))
        """
        return self._defined_tags

    @defined_tags.setter
    def defined_tags(self, defined_tags):
        """
        Sets the defined_tags of this CreateLogAnalyticsObjectCollectionRuleDetails.
        Defined tags for this resource. Each key is predefined and scoped to a namespace.
        Example: `{\"foo-namespace\": {\"bar-key\": \"value\"}}`


        :param defined_tags: The defined_tags of this CreateLogAnalyticsObjectCollectionRuleDetails.
        :type: dict(str, dict(str, object))
        """
        self._defined_tags = defined_tags

    @property
    def freeform_tags(self):
        """
        Gets the freeform_tags of this CreateLogAnalyticsObjectCollectionRuleDetails.
        Simple key-value pair that is applied without any predefined name, type or scope. Exists for cross-compatibility only.
        Example: `{\"bar-key\": \"value\"}`


        :return: The freeform_tags of this CreateLogAnalyticsObjectCollectionRuleDetails.
        :rtype: dict(str, str)
        """
        return self._freeform_tags

    @freeform_tags.setter
    def freeform_tags(self, freeform_tags):
        """
        Sets the freeform_tags of this CreateLogAnalyticsObjectCollectionRuleDetails.
        Simple key-value pair that is applied without any predefined name, type or scope. Exists for cross-compatibility only.
        Example: `{\"bar-key\": \"value\"}`


        :param freeform_tags: The freeform_tags of this CreateLogAnalyticsObjectCollectionRuleDetails.
        :type: dict(str, str)
        """
        self._freeform_tags = freeform_tags

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2020, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class NodeDetails(object):
    """
    Node details associated with a network.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new NodeDetails object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param hostname:
            The value to assign to the hostname property of this NodeDetails.
        :type hostname: str

        :param ip:
            The value to assign to the ip property of this NodeDetails.
        :type ip: str

        :param vip_hostname:
            The value to assign to the vip_hostname property of this NodeDetails.
        :type vip_hostname: str

        :param vip:
            The value to assign to the vip property of this NodeDetails.
        :type vip: str

        """
        self.swagger_types = {
            'hostname': 'str',
            'ip': 'str',
            'vip_hostname': 'str',
            'vip': 'str'
        }

        self.attribute_map = {
            'hostname': 'hostname',
            'ip': 'ip',
            'vip_hostname': 'vipHostname',
            'vip': 'vip'
        }

        self._hostname = None
        self._ip = None
        self._vip_hostname = None
        self._vip = None

    @property
    def hostname(self):
        """
        **[Required]** Gets the hostname of this NodeDetails.
        The node host name.


        :return: The hostname of this NodeDetails.
        :rtype: str
        """
        return self._hostname

    @hostname.setter
    def hostname(self, hostname):
        """
        Sets the hostname of this NodeDetails.
        The node host name.


        :param hostname: The hostname of this NodeDetails.
        :type: str
        """
        self._hostname = hostname

    @property
    def ip(self):
        """
        **[Required]** Gets the ip of this NodeDetails.
        The node IP address.


        :return: The ip of this NodeDetails.
        :rtype: str
        """
        return self._ip

    @ip.setter
    def ip(self, ip):
        """
        Sets the ip of this NodeDetails.
        The node IP address.


        :param ip: The ip of this NodeDetails.
        :type: str
        """
        self._ip = ip

    @property
    def vip_hostname(self):
        """
        Gets the vip_hostname of this NodeDetails.
        The node virtual IP (VIP) host name.


        :return: The vip_hostname of this NodeDetails.
        :rtype: str
        """
        return self._vip_hostname

    @vip_hostname.setter
    def vip_hostname(self, vip_hostname):
        """
        Sets the vip_hostname of this NodeDetails.
        The node virtual IP (VIP) host name.


        :param vip_hostname: The vip_hostname of this NodeDetails.
        :type: str
        """
        self._vip_hostname = vip_hostname

    @property
    def vip(self):
        """
        Gets the vip of this NodeDetails.
        The node virtual IP (VIP) address.


        :return: The vip of this NodeDetails.
        :rtype: str
        """
        return self._vip

    @vip.setter
    def vip(self, vip):
        """
        Sets the vip of this NodeDetails.
        The node virtual IP (VIP) address.


        :param vip: The vip of this NodeDetails.
        :type: str
        """
        self._vip = vip

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2020, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class ReportTypeSummary(object):
    """
    The model of the description of a report.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new ReportTypeSummary object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param report_type:
            The value to assign to the report_type property of this ReportTypeSummary.
        :type report_type: str

        :param name:
            The value to assign to the name property of this ReportTypeSummary.
        :type name: str

        :param description:
            The value to assign to the description property of this ReportTypeSummary.
        :type description: str

        :param columns:
            The value to assign to the columns property of this ReportTypeSummary.
        :type columns: list[str]

        """
        self.swagger_types = {
            'report_type': 'str',
            'name': 'str',
            'description': 'str',
            'columns': 'list[str]'
        }

        self.attribute_map = {
            'report_type': 'reportType',
            'name': 'name',
            'description': 'description',
            'columns': 'columns'
        }

        self._report_type = None
        self._name = None
        self._description = None
        self._columns = None

    @property
    def report_type(self):
        """
        Gets the report_type of this ReportTypeSummary.
        The type of report.


        :return: The report_type of this ReportTypeSummary.
        :rtype: str
        """
        return self._report_type

    @report_type.setter
    def report_type(self, report_type):
        """
        Sets the report_type of this ReportTypeSummary.
        The type of report.


        :param report_type: The report_type of this ReportTypeSummary.
        :type: str
        """
        self._report_type = report_type

    @property
    def name(self):
        """
        Gets the name of this ReportTypeSummary.
        The name of the report.


        :return: The name of this ReportTypeSummary.
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """
        Sets the name of this ReportTypeSummary.
        The name of the report.


        :param name: The name of this ReportTypeSummary.
        :type: str
        """
        self._name = name

    @property
    def description(self):
        """
        Gets the description of this ReportTypeSummary.
        A description of the report.


        :return: The description of this ReportTypeSummary.
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """
        Sets the description of this ReportTypeSummary.
        A description of the report.


        :param description: The description of this ReportTypeSummary.
        :type: str
        """
        self._description = description

    @property
    def columns(self):
        """
        Gets the columns of this ReportTypeSummary.
        The columns in the report.


        :return: The columns of this ReportTypeSummary.
        :rtype: list[str]
        """
        return self._columns

    @columns.setter
    def columns(self, columns):
        """
        Sets the columns of this ReportTypeSummary.
        The columns in the report.


        :param columns: The columns of this ReportTypeSummary.
        :type: list[str]
        """
        self._columns = columns

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2020, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class ArchivingConfiguration(object):
    """
    configuration for archiving data in object storage
    """

    def __init__(self, **kwargs):
        """
        Initializes a new ArchivingConfiguration object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param active_storage_duration:
            The value to assign to the active_storage_duration property of this ArchivingConfiguration.
        :type active_storage_duration: str

        :param archival_storage_duration:
            The value to assign to the archival_storage_duration property of this ArchivingConfiguration.
        :type archival_storage_duration: str

        """
        self.swagger_types = {
            'active_storage_duration': 'str',
            'archival_storage_duration': 'str'
        }

        self.attribute_map = {
            'active_storage_duration': 'activeStorageDuration',
            'archival_storage_duration': 'archivalStorageDuration'
        }

        self._active_storage_duration = None
        self._archival_storage_duration = None

    @property
    def active_storage_duration(self):
        """
        Gets the active_storage_duration of this ArchivingConfiguration.
        duration in active storage before data is archived, as described in
        https://en.wikipedia.org/wiki/ISO_8601#Durations.
        The largest supported unit is D, e.g. P365D (not P1Y) or P14D (not P2W).


        :return: The active_storage_duration of this ArchivingConfiguration.
        :rtype: str
        """
        return self._active_storage_duration

    @active_storage_duration.setter
    def active_storage_duration(self, active_storage_duration):
        """
        Sets the active_storage_duration of this ArchivingConfiguration.
        duration in active storage before data is archived, as described in
        https://en.wikipedia.org/wiki/ISO_8601#Durations.
        The largest supported unit is D, e.g. P365D (not P1Y) or P14D (not P2W).


        :param active_storage_duration: The active_storage_duration of this ArchivingConfiguration.
        :type: str
        """
        self._active_storage_duration = active_storage_duration

    @property
    def archival_storage_duration(self):
        """
        Gets the archival_storage_duration of this ArchivingConfiguration.
        duration before data is deleted from object storage, as described in
        https://en.wikipedia.org/wiki/ISO_8601#Durations
        The largest supported unit is D, e.g. P365D (not P1Y) or P14D (not P2W).


        :return: The archival_storage_duration of this ArchivingConfiguration.
        :rtype: str
        """
        return self._archival_storage_duration

    @archival_storage_duration.setter
    def archival_storage_duration(self, archival_storage_duration):
        """
        Sets the archival_storage_duration of this ArchivingConfiguration.
        duration before data is deleted from object storage, as described in
        https://en.wikipedia.org/wiki/ISO_8601#Durations
        The largest supported unit is D, e.g. P365D (not P1Y) or P14D (not P2W).


        :param archival_storage_duration: The archival_storage_duration of this ArchivingConfiguration.
        :type: str
        """
        self._archival_storage_duration = archival_storage_duration

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2020, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class InstanceConfigurationLaunchInstanceShapeConfigDetails(object):
    """
    The shape configuration requested for the instance.

    If the parameter is provided, the instance is created
    with the resources that you specify. If some properties are missing or
    the entire parameter is not provided, the instance is created with the default
    configuration values for the `shape` that you specify.

    Each shape only supports certain configurable values. If the values that you provid are not valid for the
    specified `shape`, an error is returned.

    For more information about customizing the resources that are allocated to a flexible shapes, see
    `Flexible Shapes`__.

    __ https://docs.cloud.oracle.com/Content/Compute/References/computeshapes.htm#flexible
    """

    def __init__(self, **kwargs):
        """
        Initializes a new InstanceConfigurationLaunchInstanceShapeConfigDetails object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param ocpus:
            The value to assign to the ocpus property of this InstanceConfigurationLaunchInstanceShapeConfigDetails.
        :type ocpus: float

        :param memory_in_gbs:
            The value to assign to the memory_in_gbs property of this InstanceConfigurationLaunchInstanceShapeConfigDetails.
        :type memory_in_gbs: float

        """
        self.swagger_types = {
            'ocpus': 'float',
            'memory_in_gbs': 'float'
        }

        self.attribute_map = {
            'ocpus': 'ocpus',
            'memory_in_gbs': 'memoryInGBs'
        }

        self._ocpus = None
        self._memory_in_gbs = None

    @property
    def ocpus(self):
        """
        Gets the ocpus of this InstanceConfigurationLaunchInstanceShapeConfigDetails.
        The total number of OCPUs available to the instance.


        :return: The ocpus of this InstanceConfigurationLaunchInstanceShapeConfigDetails.
        :rtype: float
        """
        return self._ocpus

    @ocpus.setter
    def ocpus(self, ocpus):
        """
        Sets the ocpus of this InstanceConfigurationLaunchInstanceShapeConfigDetails.
        The total number of OCPUs available to the instance.


        :param ocpus: The ocpus of this InstanceConfigurationLaunchInstanceShapeConfigDetails.
        :type: float
        """
        self._ocpus = ocpus

    @property
    def memory_in_gbs(self):
        """
        Gets the memory_in_gbs of this InstanceConfigurationLaunchInstanceShapeConfigDetails.
        The total amount of memory available to the instance, in gigabytes.


        :return: The memory_in_gbs of this InstanceConfigurationLaunchInstanceShapeConfigDetails.
        :rtype: float
        """
        return self._memory_in_gbs

    @memory_in_gbs.setter
    def memory_in_gbs(self, memory_in_gbs):
        """
        Sets the memory_in_gbs of this InstanceConfigurationLaunchInstanceShapeConfigDetails.
        The total amount of memory available to the instance, in gigabytes.


        :param memory_in_gbs: The memory_in_gbs of this InstanceConfigurationLaunchInstanceShapeConfigDetails.
        :type: float
        """
        self._memory_in_gbs = memory_in_gbs

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2020, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.

from __future__ import absolute_import

from .change_management_dashboards_compartment_details import ChangeManagementDashboardsCompartmentDetails
from .change_management_saved_searches_compartment_details import ChangeManagementSavedSearchesCompartmentDetails
from .create_management_dashboard_details import CreateManagementDashboardDetails
from .create_management_saved_search_details import CreateManagementSavedSearchDetails
from .management_dashboard import ManagementDashboard
from .management_dashboard_collection import ManagementDashboardCollection
from .management_dashboard_export_details import ManagementDashboardExportDetails
from .management_dashboard_for_import_export_details import ManagementDashboardForImportExportDetails
from .management_dashboard_import_details import ManagementDashboardImportDetails
from .management_dashboard_summary import ManagementDashboardSummary
from .management_dashboard_tile_details import ManagementDashboardTileDetails
from .management_saved_search import ManagementSavedSearch
from .management_saved_search_collection import ManagementSavedSearchCollection
from .management_saved_search_for_import_details import ManagementSavedSearchForImportDetails
from .management_saved_search_summary import ManagementSavedSearchSummary
from .update_management_dashboard_details import UpdateManagementDashboardDetails
from .update_management_saved_search_details import UpdateManagementSavedSearchDetails

# Maps type names to classes for management_dashboard services.
management_dashboard_type_mapping = {
    "ChangeManagementDashboardsCompartmentDetails": ChangeManagementDashboardsCompartmentDetails,
    "ChangeManagementSavedSearchesCompartmentDetails": ChangeManagementSavedSearchesCompartmentDetails,
    "CreateManagementDashboardDetails": CreateManagementDashboardDetails,
    "CreateManagementSavedSearchDetails": CreateManagementSavedSearchDetails,
    "ManagementDashboard": ManagementDashboard,
    "ManagementDashboardCollection": ManagementDashboardCollection,
    "ManagementDashboardExportDetails": ManagementDashboardExportDetails,
    "ManagementDashboardForImportExportDetails": ManagementDashboardForImportExportDetails,
    "ManagementDashboardImportDetails": ManagementDashboardImportDetails,
    "ManagementDashboardSummary": ManagementDashboardSummary,
    "ManagementDashboardTileDetails": ManagementDashboardTileDetails,
    "ManagementSavedSearch": ManagementSavedSearch,
    "ManagementSavedSearchCollection": ManagementSavedSearchCollection,
    "ManagementSavedSearchForImportDetails": ManagementSavedSearchForImportDetails,
    "ManagementSavedSearchSummary": ManagementSavedSearchSummary,
    "UpdateManagementDashboardDetails": UpdateManagementDashboardDetails,
    "UpdateManagementSavedSearchDetails": UpdateManagementSavedSearchDetails
}



# coding: utf-8
# Copyright (c) 2016, 2020, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class AssociatedDatabaseDetails(object):
    """
    Databases associated with a backup destination
    """

    def __init__(self, **kwargs):
        """
        Initializes a new AssociatedDatabaseDetails object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param id:
            The value to assign to the id property of this AssociatedDatabaseDetails.
        :type id: str

        :param db_name:
            The value to assign to the db_name property of this AssociatedDatabaseDetails.
        :type db_name: str

        """
        self.swagger_types = {
            'id': 'str',
            'db_name': 'str'
        }

        self.attribute_map = {
            'id': 'id',
            'db_name': 'dbName'
        }

        self._id = None
        self._db_name = None

    @property
    def id(self):
        """
        Gets the id of this AssociatedDatabaseDetails.
        The database `OCID`__.

        __ https://docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm


        :return: The id of this AssociatedDatabaseDetails.
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """
        Sets the id of this AssociatedDatabaseDetails.
        The database `OCID`__.

        __ https://docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm


        :param id: The id of this AssociatedDatabaseDetails.
        :type: str
        """
        self._id = id

    @property
    def db_name(self):
        """
        Gets the db_name of this AssociatedDatabaseDetails.
        The display name of the database that is associated with the backup destination.


        :return: The db_name of this AssociatedDatabaseDetails.
        :rtype: str
        """
        return self._db_name

    @db_name.setter
    def db_name(self, db_name):
        """
        Sets the db_name of this AssociatedDatabaseDetails.
        The display name of the database that is associated with the backup destination.


        :param db_name: The db_name of this AssociatedDatabaseDetails.
        :type: str
        """
        self._db_name = db_name

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2020, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class Response(object):
    """
    A container object for response attributes.

    Example:

    -----
    {
    \"status\": \"200\",
    \"responseTime\": \"2019-09-18T00:10:59.278Z\",
    \"headers\": {
    \"ETag\": [
    \"<unique_ID>\"
    ],
    \"Connection\": [
    \"close\"
    ],
    \"Content-Length\": [
    \"1828\"
    ],
    \"opc-request-id\": [
    \"<unique_ID>\"
    ],
    \"Date\": [
    \"Wed, 18 Sep 2019 00:10:59 GMT\"
    ],
    \"Content-Type\": [
    \"application/json\"
    ]
    },
    \"payload\": {
    \"resourceName\": \"my_instance\",
    \"id\": \"ocid1.instance.oc1.phx.<unique_ID>\"
    },
    \"message\": null
    }
    -----
    """

    def __init__(self, **kwargs):
        """
        Initializes a new Response object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param status:
            The value to assign to the status property of this Response.
        :type status: str

        :param response_time:
            The value to assign to the response_time property of this Response.
        :type response_time: datetime

        :param headers:
            The value to assign to the headers property of this Response.
        :type headers: dict(str, list[str])

        :param payload:
            The value to assign to the payload property of this Response.
        :type payload: dict(str, object)

        :param message:
            The value to assign to the message property of this Response.
        :type message: str

        """
        self.swagger_types = {
            'status': 'str',
            'response_time': 'datetime',
            'headers': 'dict(str, list[str])',
            'payload': 'dict(str, object)',
            'message': 'str'
        }

        self.attribute_map = {
            'status': 'status',
            'response_time': 'responseTime',
            'headers': 'headers',
            'payload': 'payload',
            'message': 'message'
        }

        self._status = None
        self._response_time = None
        self._headers = None
        self._payload = None
        self._message = None

    @property
    def status(self):
        """
        Gets the status of this Response.
        The status code of the response.

        Example: `200`


        :return: The status of this Response.
        :rtype: str
        """
        return self._status

    @status.setter
    def status(self, status):
        """
        Sets the status of this Response.
        The status code of the response.

        Example: `200`


        :param status: The status of this Response.
        :type: str
        """
        self._status = status

    @property
    def response_time(self):
        """
        Gets the response_time of this Response.
        The time of the response to the audited request, expressed in
        `RFC 3339`__ timestamp format.

        Example: `2019-09-18T00:10:59.278Z`

        __ https://tools.ietf.org/html/rfc3339


        :return: The response_time of this Response.
        :rtype: datetime
        """
        return self._response_time

    @response_time.setter
    def response_time(self, response_time):
        """
        Sets the response_time of this Response.
        The time of the response to the audited request, expressed in
        `RFC 3339`__ timestamp format.

        Example: `2019-09-18T00:10:59.278Z`

        __ https://tools.ietf.org/html/rfc3339


        :param response_time: The response_time of this Response.
        :type: datetime
        """
        self._response_time = response_time

    @property
    def headers(self):
        """
        Gets the headers of this Response.
        The headers of the response.

        Example:

          -----
            {
              \"ETag\": [
                \"<unique_ID>\"
              ],
              \"Connection\": [
                \"close\"
              ],
              \"Content-Length\": [
                \"1828\"
              ],
              \"opc-request-id\": [
                \"<unique_ID>\"
              ],
              \"Date\": [
                \"Wed, 18 Sep 2019 00:10:59 GMT\"
              ],
              \"Content-Type\": [
                \"application/json\"
              ]
            }
          -----


        :return: The headers of this Response.
        :rtype: dict(str, list[str])
        """
        return self._headers

    @headers.setter
    def headers(self, headers):
        """
        Sets the headers of this Response.
        The headers of the response.

        Example:

          -----
            {
              \"ETag\": [
                \"<unique_ID>\"
              ],
              \"Connection\": [
                \"close\"
              ],
              \"Content-Length\": [
                \"1828\"
              ],
              \"opc-request-id\": [
                \"<unique_ID>\"
              ],
              \"Date\": [
                \"Wed, 18 Sep 2019 00:10:59 GMT\"
              ],
              \"Content-Type\": [
                \"application/json\"
              ]
            }
          -----


        :param headers: The headers of this Response.
        :type: dict(str, list[str])
        """
        self._headers = headers

    @property
    def payload(self):
        """
        Gets the payload of this Response.
        This value is included for backward compatibility with the Audit version 1 schema, where
        it contained metadata of interest from the response payload.

        Example:

          -----
            {
              \"resourceName\": \"my_instance\",
              \"id\": \"ocid1.instance.oc1.phx.<unique_ID>\"
            }
          -----


        :return: The payload of this Response.
        :rtype: dict(str, object)
        """
        return self._payload

    @payload.setter
    def payload(self, payload):
        """
        Sets the payload of this Response.
        This value is included for backward compatibility with the Audit version 1 schema, where
        it contained metadata of interest from the response payload.

        Example:

          -----
            {
              \"resourceName\": \"my_instance\",
              \"id\": \"ocid1.instance.oc1.phx.<unique_ID>\"
            }
          -----


        :param payload: The payload of this Response.
        :type: dict(str, object)
        """
        self._payload = payload

    @property
    def message(self):
        """
        Gets the message of this Response.
        A friendly description of what happened during the operation. Use this for troubleshooting.


        :return: The message of this Response.
        :rtype: str
        """
        return self._message

    @message.setter
    def message(self, message):
        """
        Sets the message of this Response.
        A friendly description of what happened during the operation. Use this for troubleshooting.


        :param message: The message of this Response.
        :type: str
        """
        self._message = message

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2020, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.

from __future__ import absolute_import

from .analytics_instance import AnalyticsInstance
from .analytics_instance_summary import AnalyticsInstanceSummary
from .capacity import Capacity
from .change_analytics_instance_network_endpoint_details import ChangeAnalyticsInstanceNetworkEndpointDetails
from .change_compartment_details import ChangeCompartmentDetails
from .create_analytics_instance_details import CreateAnalyticsInstanceDetails
from .network_endpoint_details import NetworkEndpointDetails
from .private_endpoint_details import PrivateEndpointDetails
from .public_endpoint_details import PublicEndpointDetails
from .scale_analytics_instance_details import ScaleAnalyticsInstanceDetails
from .update_analytics_instance_details import UpdateAnalyticsInstanceDetails
from .virtual_cloud_network import VirtualCloudNetwork
from .work_request import WorkRequest
from .work_request_error import WorkRequestError
from .work_request_log import WorkRequestLog
from .work_request_resource import WorkRequestResource
from .work_request_summary import WorkRequestSummary

# Maps type names to classes for analytics services.
analytics_type_mapping = {
    "AnalyticsInstance": AnalyticsInstance,
    "AnalyticsInstanceSummary": AnalyticsInstanceSummary,
    "Capacity": Capacity,
    "ChangeAnalyticsInstanceNetworkEndpointDetails": ChangeAnalyticsInstanceNetworkEndpointDetails,
    "ChangeCompartmentDetails": ChangeCompartmentDetails,
    "CreateAnalyticsInstanceDetails": CreateAnalyticsInstanceDetails,
    "NetworkEndpointDetails": NetworkEndpointDetails,
    "PrivateEndpointDetails": PrivateEndpointDetails,
    "PublicEndpointDetails": PublicEndpointDetails,
    "ScaleAnalyticsInstanceDetails": ScaleAnalyticsInstanceDetails,
    "UpdateAnalyticsInstanceDetails": UpdateAnalyticsInstanceDetails,
    "VirtualCloudNetwork": VirtualCloudNetwork,
    "WorkRequest": WorkRequest,
    "WorkRequestError": WorkRequestError,
    "WorkRequestLog": WorkRequestLog,
    "WorkRequestResource": WorkRequestResource,
    "WorkRequestSummary": WorkRequestSummary
}



# coding: utf-8
# Copyright (c) 2016, 2020, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class CreateCertificateDetails(object):
    """
    The data used to create a new SSL certificate.

    **Warning:** Oracle recommends that you avoid using any confidential information when you supply string values using the API.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new CreateCertificateDetails object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param compartment_id:
            The value to assign to the compartment_id property of this CreateCertificateDetails.
        :type compartment_id: str

        :param display_name:
            The value to assign to the display_name property of this CreateCertificateDetails.
        :type display_name: str

        :param certificate_data:
            The value to assign to the certificate_data property of this CreateCertificateDetails.
        :type certificate_data: str

        :param private_key_data:
            The value to assign to the private_key_data property of this CreateCertificateDetails.
        :type private_key_data: str

        :param is_trust_verification_disabled:
            The value to assign to the is_trust_verification_disabled property of this CreateCertificateDetails.
        :type is_trust_verification_disabled: bool

        :param freeform_tags:
            The value to assign to the freeform_tags property of this CreateCertificateDetails.
        :type freeform_tags: dict(str, str)

        :param defined_tags:
            The value to assign to the defined_tags property of this CreateCertificateDetails.
        :type defined_tags: dict(str, dict(str, object))

        """
        self.swagger_types = {
            'compartment_id': 'str',
            'display_name': 'str',
            'certificate_data': 'str',
            'private_key_data': 'str',
            'is_trust_verification_disabled': 'bool',
            'freeform_tags': 'dict(str, str)',
            'defined_tags': 'dict(str, dict(str, object))'
        }

        self.attribute_map = {
            'compartment_id': 'compartmentId',
            'display_name': 'displayName',
            'certificate_data': 'certificateData',
            'private_key_data': 'privateKeyData',
            'is_trust_verification_disabled': 'isTrustVerificationDisabled',
            'freeform_tags': 'freeformTags',
            'defined_tags': 'definedTags'
        }

        self._compartment_id = None
        self._display_name = None
        self._certificate_data = None
        self._private_key_data = None
        self._is_trust_verification_disabled = None
        self._freeform_tags = None
        self._defined_tags = None

    @property
    def compartment_id(self):
        """
        **[Required]** Gets the compartment_id of this CreateCertificateDetails.
        The `OCID`__ of the compartment in which to create the SSL certificate.

        __ https://docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm


        :return: The compartment_id of this CreateCertificateDetails.
        :rtype: str
        """
        return self._compartment_id

    @compartment_id.setter
    def compartment_id(self, compartment_id):
        """
        Sets the compartment_id of this CreateCertificateDetails.
        The `OCID`__ of the compartment in which to create the SSL certificate.

        __ https://docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm


        :param compartment_id: The compartment_id of this CreateCertificateDetails.
        :type: str
        """
        self._compartment_id = compartment_id

    @property
    def display_name(self):
        """
        Gets the display_name of this CreateCertificateDetails.
        A user-friendly name for the SSL certificate. The name can be changed and does not need to be unique.


        :return: The display_name of this CreateCertificateDetails.
        :rtype: str
        """
        return self._display_name

    @display_name.setter
    def display_name(self, display_name):
        """
        Sets the display_name of this CreateCertificateDetails.
        A user-friendly name for the SSL certificate. The name can be changed and does not need to be unique.


        :param display_name: The display_name of this CreateCertificateDetails.
        :type: str
        """
        self._display_name = display_name

    @property
    def certificate_data(self):
        """
        **[Required]** Gets the certificate_data of this CreateCertificateDetails.
        The data of the SSL certificate.


        **Note:** Many SSL certificate providers require an intermediate certificate chain to ensure a trusted status.
        If your SSL certificate requires an intermediate certificate chain, please append the intermediate certificate
        key in the `certificateData` field after the leaf certificate issued by the SSL certificate provider. If you
        are unsure if your certificate requires an intermediate certificate chain, see your certificate
        provider's documentation.


        The example below shows an intermediate certificate appended to a leaf certificate.


        :return: The certificate_data of this CreateCertificateDetails.
        :rtype: str
        """
        return self._certificate_data

    @certificate_data.setter
    def certificate_data(self, certificate_data):
        """
        Sets the certificate_data of this CreateCertificateDetails.
        The data of the SSL certificate.


        **Note:** Many SSL certificate providers require an intermediate certificate chain to ensure a trusted status.
        If your SSL certificate requires an intermediate certificate chain, please append the intermediate certificate
        key in the `certificateData` field after the leaf certificate issued by the SSL certificate provider. If you
        are unsure if your certificate requires an intermediate certificate chain, see your certificate
        provider's documentation.


        The example below shows an intermediate certificate appended to a leaf certificate.


        :param certificate_data: The certificate_data of this CreateCertificateDetails.
        :type: str
        """
        self._certificate_data = certificate_data

    @property
    def private_key_data(self):
        """
        **[Required]** Gets the private_key_data of this CreateCertificateDetails.
        The private key of the SSL certificate.


        :return: The private_key_data of this CreateCertificateDetails.
        :rtype: str
        """
        return self._private_key_data

    @private_key_data.setter
    def private_key_data(self, private_key_data):
        """
        Sets the private_key_data of this CreateCertificateDetails.
        The private key of the SSL certificate.


        :param private_key_data: The private_key_data of this CreateCertificateDetails.
        :type: str
        """
        self._private_key_data = private_key_data

    @property
    def is_trust_verification_disabled(self):
        """
        Gets the is_trust_verification_disabled of this CreateCertificateDetails.
        Set to `true` if the SSL certificate is self-signed.


        :return: The is_trust_verification_disabled of this CreateCertificateDetails.
        :rtype: bool
        """
        return self._is_trust_verification_disabled

    @is_trust_verification_disabled.setter
    def is_trust_verification_disabled(self, is_trust_verification_disabled):
        """
        Sets the is_trust_verification_disabled of this CreateCertificateDetails.
        Set to `true` if the SSL certificate is self-signed.


        :param is_trust_verification_disabled: The is_trust_verification_disabled of this CreateCertificateDetails.
        :type: bool
        """
        self._is_trust_verification_disabled = is_trust_verification_disabled

    @property
    def freeform_tags(self):
        """
        Gets the freeform_tags of this CreateCertificateDetails.
        Free-form tags for this resource. Each tag is a simple key-value pair with no predefined name, type, or namespace.
        For more information, see `Resource Tags`__.

        Example: `{\"Department\": \"Finance\"}`

        __ https://docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm


        :return: The freeform_tags of this CreateCertificateDetails.
        :rtype: dict(str, str)
        """
        return self._freeform_tags

    @freeform_tags.setter
    def freeform_tags(self, freeform_tags):
        """
        Sets the freeform_tags of this CreateCertificateDetails.
        Free-form tags for this resource. Each tag is a simple key-value pair with no predefined name, type, or namespace.
        For more information, see `Resource Tags`__.

        Example: `{\"Department\": \"Finance\"}`

        __ https://docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm


        :param freeform_tags: The freeform_tags of this CreateCertificateDetails.
        :type: dict(str, str)
        """
        self._freeform_tags = freeform_tags

    @property
    def defined_tags(self):
        """
        Gets the defined_tags of this CreateCertificateDetails.
        Defined tags for this resource. Each key is predefined and scoped to a namespace.
        For more information, see `Resource Tags`__.

        Example: `{\"Operations\": {\"CostCenter\": \"42\"}}`

        __ https://docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm


        :return: The defined_tags of this CreateCertificateDetails.
        :rtype: dict(str, dict(str, object))
        """
        return self._defined_tags

    @defined_tags.setter
    def defined_tags(self, defined_tags):
        """
        Sets the defined_tags of this CreateCertificateDetails.
        Defined tags for this resource. Each key is predefined and scoped to a namespace.
        For more information, see `Resource Tags`__.

        Example: `{\"Operations\": {\"CostCenter\": \"42\"}}`

        __ https://docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm


        :param defined_tags: The defined_tags of this CreateCertificateDetails.
        :type: dict(str, dict(str, object))
        """
        self._defined_tags = defined_tags

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2020, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class ApiSpecificationRoute(object):
    """
    A single route that forwards requests to a particular backend and may contain some additional policies.
    """

    #: A constant which can be used with the methods property of a ApiSpecificationRoute.
    #: This constant has a value of "ANY"
    METHODS_ANY = "ANY"

    #: A constant which can be used with the methods property of a ApiSpecificationRoute.
    #: This constant has a value of "HEAD"
    METHODS_HEAD = "HEAD"

    #: A constant which can be used with the methods property of a ApiSpecificationRoute.
    #: This constant has a value of "GET"
    METHODS_GET = "GET"

    #: A constant which can be used with the methods property of a ApiSpecificationRoute.
    #: This constant has a value of "POST"
    METHODS_POST = "POST"

    #: A constant which can be used with the methods property of a ApiSpecificationRoute.
    #: This constant has a value of "PUT"
    METHODS_PUT = "PUT"

    #: A constant which can be used with the methods property of a ApiSpecificationRoute.
    #: This constant has a value of "PATCH"
    METHODS_PATCH = "PATCH"

    #: A constant which can be used with the methods property of a ApiSpecificationRoute.
    #: This constant has a value of "DELETE"
    METHODS_DELETE = "DELETE"

    #: A constant which can be used with the methods property of a ApiSpecificationRoute.
    #: This constant has a value of "OPTIONS"
    METHODS_OPTIONS = "OPTIONS"

    def __init__(self, **kwargs):
        """
        Initializes a new ApiSpecificationRoute object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param path:
            The value to assign to the path property of this ApiSpecificationRoute.
        :type path: str

        :param methods:
            The value to assign to the methods property of this ApiSpecificationRoute.
            Allowed values for items in this list are: "ANY", "HEAD", "GET", "POST", "PUT", "PATCH", "DELETE", "OPTIONS", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type methods: list[str]

        :param request_policies:
            The value to assign to the request_policies property of this ApiSpecificationRoute.
        :type request_policies: ApiSpecificationRouteRequestPolicies

        :param response_policies:
            The value to assign to the response_policies property of this ApiSpecificationRoute.
        :type response_policies: ApiSpecificationRouteResponsePolicies

        :param logging_policies:
            The value to assign to the logging_policies property of this ApiSpecificationRoute.
        :type logging_policies: ApiSpecificationLoggingPolicies

        :param backend:
            The value to assign to the backend property of this ApiSpecificationRoute.
        :type backend: ApiSpecificationRouteBackend

        """
        self.swagger_types = {
            'path': 'str',
            'methods': 'list[str]',
            'request_policies': 'ApiSpecificationRouteRequestPolicies',
            'response_policies': 'ApiSpecificationRouteResponsePolicies',
            'logging_policies': 'ApiSpecificationLoggingPolicies',
            'backend': 'ApiSpecificationRouteBackend'
        }

        self.attribute_map = {
            'path': 'path',
            'methods': 'methods',
            'request_policies': 'requestPolicies',
            'response_policies': 'responsePolicies',
            'logging_policies': 'loggingPolicies',
            'backend': 'backend'
        }

        self._path = None
        self._methods = None
        self._request_policies = None
        self._response_policies = None
        self._logging_policies = None
        self._backend = None

    @property
    def path(self):
        """
        **[Required]** Gets the path of this ApiSpecificationRoute.
        A URL path pattern that must be matched on this route. The path pattern may contain a subset of RFC 6570 identifiers
        to allow wildcard and parameterized matching.


        :return: The path of this ApiSpecificationRoute.
        :rtype: str
        """
        return self._path

    @path.setter
    def path(self, path):
        """
        Sets the path of this ApiSpecificationRoute.
        A URL path pattern that must be matched on this route. The path pattern may contain a subset of RFC 6570 identifiers
        to allow wildcard and parameterized matching.


        :param path: The path of this ApiSpecificationRoute.
        :type: str
        """
        self._path = path

    @property
    def methods(self):
        """
        Gets the methods of this ApiSpecificationRoute.
        A list of allowed methods on this route.

        Allowed values for items in this list are: "ANY", "HEAD", "GET", "POST", "PUT", "PATCH", "DELETE", "OPTIONS", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The methods of this ApiSpecificationRoute.
        :rtype: list[str]
        """
        return self._methods

    @methods.setter
    def methods(self, methods):
        """
        Sets the methods of this ApiSpecificationRoute.
        A list of allowed methods on this route.


        :param methods: The methods of this ApiSpecificationRoute.
        :type: list[str]
        """
        allowed_values = ["ANY", "HEAD", "GET", "POST", "PUT", "PATCH", "DELETE", "OPTIONS"]
        if methods:
            methods[:] = ['UNKNOWN_ENUM_VALUE' if not value_allowed_none_or_none_sentinel(x, allowed_values) else x for x in methods]
        self._methods = methods

    @property
    def request_policies(self):
        """
        Gets the request_policies of this ApiSpecificationRoute.

        :return: The request_policies of this ApiSpecificationRoute.
        :rtype: ApiSpecificationRouteRequestPolicies
        """
        return self._request_policies

    @request_policies.setter
    def request_policies(self, request_policies):
        """
        Sets the request_policies of this ApiSpecificationRoute.

        :param request_policies: The request_policies of this ApiSpecificationRoute.
        :type: ApiSpecificationRouteRequestPolicies
        """
        self._request_policies = request_policies

    @property
    def response_policies(self):
        """
        Gets the response_policies of this ApiSpecificationRoute.

        :return: The response_policies of this ApiSpecificationRoute.
        :rtype: ApiSpecificationRouteResponsePolicies
        """
        return self._response_policies

    @response_policies.setter
    def response_policies(self, response_policies):
        """
        Sets the response_policies of this ApiSpecificationRoute.

        :param response_policies: The response_policies of this ApiSpecificationRoute.
        :type: ApiSpecificationRouteResponsePolicies
        """
        self._response_policies = response_policies

    @property
    def logging_policies(self):
        """
        Gets the logging_policies of this ApiSpecificationRoute.

        :return: The logging_policies of this ApiSpecificationRoute.
        :rtype: ApiSpecificationLoggingPolicies
        """
        return self._logging_policies

    @logging_policies.setter
    def logging_policies(self, logging_policies):
        """
        Sets the logging_policies of this ApiSpecificationRoute.

        :param logging_policies: The logging_policies of this ApiSpecificationRoute.
        :type: ApiSpecificationLoggingPolicies
        """
        self._logging_policies = logging_policies

    @property
    def backend(self):
        """
        **[Required]** Gets the backend of this ApiSpecificationRoute.

        :return: The backend of this ApiSpecificationRoute.
        :rtype: ApiSpecificationRouteBackend
        """
        return self._backend

    @backend.setter
    def backend(self, backend):
        """
        Sets the backend of this ApiSpecificationRoute.

        :param backend: The backend of this ApiSpecificationRoute.
        :type: ApiSpecificationRouteBackend
        """
        self._backend = backend

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2020, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class PasswordPolicy(object):
    """
    Password policy, currently set for the given compartment.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new PasswordPolicy object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param minimum_password_length:
            The value to assign to the minimum_password_length property of this PasswordPolicy.
        :type minimum_password_length: int

        :param is_uppercase_characters_required:
            The value to assign to the is_uppercase_characters_required property of this PasswordPolicy.
        :type is_uppercase_characters_required: bool

        :param is_lowercase_characters_required:
            The value to assign to the is_lowercase_characters_required property of this PasswordPolicy.
        :type is_lowercase_characters_required: bool

        :param is_numeric_characters_required:
            The value to assign to the is_numeric_characters_required property of this PasswordPolicy.
        :type is_numeric_characters_required: bool

        :param is_special_characters_required:
            The value to assign to the is_special_characters_required property of this PasswordPolicy.
        :type is_special_characters_required: bool

        :param is_username_containment_allowed:
            The value to assign to the is_username_containment_allowed property of this PasswordPolicy.
        :type is_username_containment_allowed: bool

        """
        self.swagger_types = {
            'minimum_password_length': 'int',
            'is_uppercase_characters_required': 'bool',
            'is_lowercase_characters_required': 'bool',
            'is_numeric_characters_required': 'bool',
            'is_special_characters_required': 'bool',
            'is_username_containment_allowed': 'bool'
        }

        self.attribute_map = {
            'minimum_password_length': 'minimumPasswordLength',
            'is_uppercase_characters_required': 'isUppercaseCharactersRequired',
            'is_lowercase_characters_required': 'isLowercaseCharactersRequired',
            'is_numeric_characters_required': 'isNumericCharactersRequired',
            'is_special_characters_required': 'isSpecialCharactersRequired',
            'is_username_containment_allowed': 'isUsernameContainmentAllowed'
        }

        self._minimum_password_length = None
        self._is_uppercase_characters_required = None
        self._is_lowercase_characters_required = None
        self._is_numeric_characters_required = None
        self._is_special_characters_required = None
        self._is_username_containment_allowed = None

    @property
    def minimum_password_length(self):
        """
        Gets the minimum_password_length of this PasswordPolicy.
        Minimum password length required.


        :return: The minimum_password_length of this PasswordPolicy.
        :rtype: int
        """
        return self._minimum_password_length

    @minimum_password_length.setter
    def minimum_password_length(self, minimum_password_length):
        """
        Sets the minimum_password_length of this PasswordPolicy.
        Minimum password length required.


        :param minimum_password_length: The minimum_password_length of this PasswordPolicy.
        :type: int
        """
        self._minimum_password_length = minimum_password_length

    @property
    def is_uppercase_characters_required(self):
        """
        Gets the is_uppercase_characters_required of this PasswordPolicy.
        At least one uppercase character required.


        :return: The is_uppercase_characters_required of this PasswordPolicy.
        :rtype: bool
        """
        return self._is_uppercase_characters_required

    @is_uppercase_characters_required.setter
    def is_uppercase_characters_required(self, is_uppercase_characters_required):
        """
        Sets the is_uppercase_characters_required of this PasswordPolicy.
        At least one uppercase character required.


        :param is_uppercase_characters_required: The is_uppercase_characters_required of this PasswordPolicy.
        :type: bool
        """
        self._is_uppercase_characters_required = is_uppercase_characters_required

    @property
    def is_lowercase_characters_required(self):
        """
        Gets the is_lowercase_characters_required of this PasswordPolicy.
        At least one lower case character required.


        :return: The is_lowercase_characters_required of this PasswordPolicy.
        :rtype: bool
        """
        return self._is_lowercase_characters_required

    @is_lowercase_characters_required.setter
    def is_lowercase_characters_required(self, is_lowercase_characters_required):
        """
        Sets the is_lowercase_characters_required of this PasswordPolicy.
        At least one lower case character required.


        :param is_lowercase_characters_required: The is_lowercase_characters_required of this PasswordPolicy.
        :type: bool
        """
        self._is_lowercase_characters_required = is_lowercase_characters_required

    @property
    def is_numeric_characters_required(self):
        """
        Gets the is_numeric_characters_required of this PasswordPolicy.
        At least one numeric character required.


        :return: The is_numeric_characters_required of this PasswordPolicy.
        :rtype: bool
        """
        return self._is_numeric_characters_required

    @is_numeric_characters_required.setter
    def is_numeric_characters_required(self, is_numeric_characters_required):
        """
        Sets the is_numeric_characters_required of this PasswordPolicy.
        At least one numeric character required.


        :param is_numeric_characters_required: The is_numeric_characters_required of this PasswordPolicy.
        :type: bool
        """
        self._is_numeric_characters_required = is_numeric_characters_required

    @property
    def is_special_characters_required(self):
        """
        Gets the is_special_characters_required of this PasswordPolicy.
        At least one special character required.


        :return: The is_special_characters_required of this PasswordPolicy.
        :rtype: bool
        """
        return self._is_special_characters_required

    @is_special_characters_required.setter
    def is_special_characters_required(self, is_special_characters_required):
        """
        Sets the is_special_characters_required of this PasswordPolicy.
        At least one special character required.


        :param is_special_characters_required: The is_special_characters_required of this PasswordPolicy.
        :type: bool
        """
        self._is_special_characters_required = is_special_characters_required

    @property
    def is_username_containment_allowed(self):
        """
        Gets the is_username_containment_allowed of this PasswordPolicy.
        User name is allowed to be part of the password.


        :return: The is_username_containment_allowed of this PasswordPolicy.
        :rtype: bool
        """
        return self._is_username_containment_allowed

    @is_username_containment_allowed.setter
    def is_username_containment_allowed(self, is_username_containment_allowed):
        """
        Sets the is_username_containment_allowed of this PasswordPolicy.
        User name is allowed to be part of the password.


        :param is_username_containment_allowed: The is_username_containment_allowed of this PasswordPolicy.
        :type: bool
        """
        self._is_username_containment_allowed = is_username_containment_allowed

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2020, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class ObjectMetadata(object):
    """
    A summary type containing information about the object including its key, name and when/who created/updated it
    """

    def __init__(self, **kwargs):
        """
        Initializes a new ObjectMetadata object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param created_by:
            The value to assign to the created_by property of this ObjectMetadata.
        :type created_by: str

        :param created_by_name:
            The value to assign to the created_by_name property of this ObjectMetadata.
        :type created_by_name: str

        :param updated_by:
            The value to assign to the updated_by property of this ObjectMetadata.
        :type updated_by: str

        :param updated_by_name:
            The value to assign to the updated_by_name property of this ObjectMetadata.
        :type updated_by_name: str

        :param time_created:
            The value to assign to the time_created property of this ObjectMetadata.
        :type time_created: datetime

        :param time_updated:
            The value to assign to the time_updated property of this ObjectMetadata.
        :type time_updated: datetime

        :param aggregator_key:
            The value to assign to the aggregator_key property of this ObjectMetadata.
        :type aggregator_key: str

        :param identifier_path:
            The value to assign to the identifier_path property of this ObjectMetadata.
        :type identifier_path: str

        :param info_fields:
            The value to assign to the info_fields property of this ObjectMetadata.
        :type info_fields: dict(str, str)

        :param registry_version:
            The value to assign to the registry_version property of this ObjectMetadata.
        :type registry_version: int

        :param labels:
            The value to assign to the labels property of this ObjectMetadata.
        :type labels: list[str]

        """
        self.swagger_types = {
            'created_by': 'str',
            'created_by_name': 'str',
            'updated_by': 'str',
            'updated_by_name': 'str',
            'time_created': 'datetime',
            'time_updated': 'datetime',
            'aggregator_key': 'str',
            'identifier_path': 'str',
            'info_fields': 'dict(str, str)',
            'registry_version': 'int',
            'labels': 'list[str]'
        }

        self.attribute_map = {
            'created_by': 'createdBy',
            'created_by_name': 'createdByName',
            'updated_by': 'updatedBy',
            'updated_by_name': 'updatedByName',
            'time_created': 'timeCreated',
            'time_updated': 'timeUpdated',
            'aggregator_key': 'aggregatorKey',
            'identifier_path': 'identifierPath',
            'info_fields': 'infoFields',
            'registry_version': 'registryVersion',
            'labels': 'labels'
        }

        self._created_by = None
        self._created_by_name = None
        self._updated_by = None
        self._updated_by_name = None
        self._time_created = None
        self._time_updated = None
        self._aggregator_key = None
        self._identifier_path = None
        self._info_fields = None
        self._registry_version = None
        self._labels = None

    @property
    def created_by(self):
        """
        Gets the created_by of this ObjectMetadata.
        The user that created the object.


        :return: The created_by of this ObjectMetadata.
        :rtype: str
        """
        return self._created_by

    @created_by.setter
    def created_by(self, created_by):
        """
        Sets the created_by of this ObjectMetadata.
        The user that created the object.


        :param created_by: The created_by of this ObjectMetadata.
        :type: str
        """
        self._created_by = created_by

    @property
    def created_by_name(self):
        """
        Gets the created_by_name of this ObjectMetadata.
        The user that created the object.


        :return: The created_by_name of this ObjectMetadata.
        :rtype: str
        """
        return self._created_by_name

    @created_by_name.setter
    def created_by_name(self, created_by_name):
        """
        Sets the created_by_name of this ObjectMetadata.
        The user that created the object.


        :param created_by_name: The created_by_name of this ObjectMetadata.
        :type: str
        """
        self._created_by_name = created_by_name

    @property
    def updated_by(self):
        """
        Gets the updated_by of this ObjectMetadata.
        The user that updated the object.


        :return: The updated_by of this ObjectMetadata.
        :rtype: str
        """
        return self._updated_by

    @updated_by.setter
    def updated_by(self, updated_by):
        """
        Sets the updated_by of this ObjectMetadata.
        The user that updated the object.


        :param updated_by: The updated_by of this ObjectMetadata.
        :type: str
        """
        self._updated_by = updated_by

    @property
    def updated_by_name(self):
        """
        Gets the updated_by_name of this ObjectMetadata.
        The user that updated the object.


        :return: The updated_by_name of this ObjectMetadata.
        :rtype: str
        """
        return self._updated_by_name

    @updated_by_name.setter
    def updated_by_name(self, updated_by_name):
        """
        Sets the updated_by_name of this ObjectMetadata.
        The user that updated the object.


        :param updated_by_name: The updated_by_name of this ObjectMetadata.
        :type: str
        """
        self._updated_by_name = updated_by_name

    @property
    def time_created(self):
        """
        Gets the time_created of this ObjectMetadata.
        The date and time that the object was created.


        :return: The time_created of this ObjectMetadata.
        :rtype: datetime
        """
        return self._time_created

    @time_created.setter
    def time_created(self, time_created):
        """
        Sets the time_created of this ObjectMetadata.
        The date and time that the object was created.


        :param time_created: The time_created of this ObjectMetadata.
        :type: datetime
        """
        self._time_created = time_created

    @property
    def time_updated(self):
        """
        Gets the time_updated of this ObjectMetadata.
        The date and time that the object was updated.


        :return: The time_updated of this ObjectMetadata.
        :rtype: datetime
        """
        return self._time_updated

    @time_updated.setter
    def time_updated(self, time_updated):
        """
        Sets the time_updated of this ObjectMetadata.
        The date and time that the object was updated.


        :param time_updated: The time_updated of this ObjectMetadata.
        :type: datetime
        """
        self._time_updated = time_updated

    @property
    def aggregator_key(self):
        """
        Gets the aggregator_key of this ObjectMetadata.
        The owning object key for this object.


        :return: The aggregator_key of this ObjectMetadata.
        :rtype: str
        """
        return self._aggregator_key

    @aggregator_key.setter
    def aggregator_key(self, aggregator_key):
        """
        Sets the aggregator_key of this ObjectMetadata.
        The owning object key for this object.


        :param aggregator_key: The aggregator_key of this ObjectMetadata.
        :type: str
        """
        self._aggregator_key = aggregator_key

    @property
    def identifier_path(self):
        """
        Gets the identifier_path of this ObjectMetadata.
        The full path to identify this object.


        :return: The identifier_path of this ObjectMetadata.
        :rtype: str
        """
        return self._identifier_path

    @identifier_path.setter
    def identifier_path(self, identifier_path):
        """
        Sets the identifier_path of this ObjectMetadata.
        The full path to identify this object.


        :param identifier_path: The identifier_path of this ObjectMetadata.
        :type: str
        """
        self._identifier_path = identifier_path

    @property
    def info_fields(self):
        """
        Gets the info_fields of this ObjectMetadata.
        infoFields


        :return: The info_fields of this ObjectMetadata.
        :rtype: dict(str, str)
        """
        return self._info_fields

    @info_fields.setter
    def info_fields(self, info_fields):
        """
        Sets the info_fields of this ObjectMetadata.
        infoFields


        :param info_fields: The info_fields of this ObjectMetadata.
        :type: dict(str, str)
        """
        self._info_fields = info_fields

    @property
    def registry_version(self):
        """
        Gets the registry_version of this ObjectMetadata.
        registryVersion


        :return: The registry_version of this ObjectMetadata.
        :rtype: int
        """
        return self._registry_version

    @registry_version.setter
    def registry_version(self, registry_version):
        """
        Sets the registry_version of this ObjectMetadata.
        registryVersion


        :param registry_version: The registry_version of this ObjectMetadata.
        :type: int
        """
        self._registry_version = registry_version

    @property
    def labels(self):
        """
        Gets the labels of this ObjectMetadata.
        Labels are keywords or tags that you can add to data assets, dataflows etc. You can define your own labels and use them to categorize content.


        :return: The labels of this ObjectMetadata.
        :rtype: list[str]
        """
        return self._labels

    @labels.setter
    def labels(self, labels):
        """
        Sets the labels of this ObjectMetadata.
        Labels are keywords or tags that you can add to data assets, dataflows etc. You can define your own labels and use them to categorize content.


        :param labels: The labels of this ObjectMetadata.
        :type: list[str]
        """
        self._labels = labels

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2020, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.

from .authorization_details import AuthorizationDetails
from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class InternalAuthorizationDetails(AuthorizationDetails):
    """
    Specifies the credentials to access the source Oracle Cloud Infrastructure - Classic environment.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new InternalAuthorizationDetails object with values from keyword arguments. The default value of the :py:attr:`~oci.application_migration.models.InternalAuthorizationDetails.type` attribute
        of this class is ``INTERNAL_COMPUTE`` and it should not be changed.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param type:
            The value to assign to the type property of this InternalAuthorizationDetails.
            Allowed values for this property are: "OCIC", "INTERNAL_COMPUTE"
        :type type: str

        :param username:
            The value to assign to the username property of this InternalAuthorizationDetails.
        :type username: str

        :param password:
            The value to assign to the password property of this InternalAuthorizationDetails.
        :type password: str

        """
        self.swagger_types = {
            'type': 'str',
            'username': 'str',
            'password': 'str'
        }

        self.attribute_map = {
            'type': 'type',
            'username': 'username',
            'password': 'password'
        }

        self._type = None
        self._username = None
        self._password = None
        self._type = 'INTERNAL_COMPUTE'

    @property
    def username(self):
        """
        **[Required]** Gets the username of this InternalAuthorizationDetails.
        User with Compute Operations role in Oracle Cloud Infrastructure - Classic.


        :return: The username of this InternalAuthorizationDetails.
        :rtype: str
        """
        return self._username

    @username.setter
    def username(self, username):
        """
        Sets the username of this InternalAuthorizationDetails.
        User with Compute Operations role in Oracle Cloud Infrastructure - Classic.


        :param username: The username of this InternalAuthorizationDetails.
        :type: str
        """
        self._username = username

    @property
    def password(self):
        """
        **[Required]** Gets the password of this InternalAuthorizationDetails.
        Password for this user.


        :return: The password of this InternalAuthorizationDetails.
        :rtype: str
        """
        return self._password

    @password.setter
    def password(self, password):
        """
        Sets the password of this InternalAuthorizationDetails.
        Password for this user.


        :param password: The password of this InternalAuthorizationDetails.
        :type: str
        """
        self._password = password

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2020, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class MigrationReplacement(object):
    """
    A record to add to a zone in replacement of contents that cannot be migrated.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new MigrationReplacement object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param rtype:
            The value to assign to the rtype property of this MigrationReplacement.
        :type rtype: str

        :param substitute_rtype:
            The value to assign to the substitute_rtype property of this MigrationReplacement.
        :type substitute_rtype: str

        :param ttl:
            The value to assign to the ttl property of this MigrationReplacement.
        :type ttl: int

        :param rdata:
            The value to assign to the rdata property of this MigrationReplacement.
        :type rdata: str

        """
        self.swagger_types = {
            'rtype': 'str',
            'substitute_rtype': 'str',
            'ttl': 'int',
            'rdata': 'str'
        }

        self.attribute_map = {
            'rtype': 'rtype',
            'substitute_rtype': 'substituteRtype',
            'ttl': 'ttl',
            'rdata': 'rdata'
        }

        self._rtype = None
        self._substitute_rtype = None
        self._ttl = None
        self._rdata = None

    @property
    def rtype(self):
        """
        **[Required]** Gets the rtype of this MigrationReplacement.
        The canonical name for the type of the replacement record, such as A or CNAME.


        :return: The rtype of this MigrationReplacement.
        :rtype: str
        """
        return self._rtype

    @rtype.setter
    def rtype(self, rtype):
        """
        Sets the rtype of this MigrationReplacement.
        The canonical name for the type of the replacement record, such as A or CNAME.


        :param rtype: The rtype of this MigrationReplacement.
        :type: str
        """
        self._rtype = rtype

    @property
    def substitute_rtype(self):
        """
        Gets the substitute_rtype of this MigrationReplacement.
        The canonical name for a substitute type of the replacement record to be used if the specified `rtype` is not allowed at the domain. The specified `ttl` and `rdata` will still apply with the substitute type.


        :return: The substitute_rtype of this MigrationReplacement.
        :rtype: str
        """
        return self._substitute_rtype

    @substitute_rtype.setter
    def substitute_rtype(self, substitute_rtype):
        """
        Sets the substitute_rtype of this MigrationReplacement.
        The canonical name for a substitute type of the replacement record to be used if the specified `rtype` is not allowed at the domain. The specified `ttl` and `rdata` will still apply with the substitute type.


        :param substitute_rtype: The substitute_rtype of this MigrationReplacement.
        :type: str
        """
        self._substitute_rtype = substitute_rtype

    @property
    def ttl(self):
        """
        **[Required]** Gets the ttl of this MigrationReplacement.
        The Time To Live of the replacement record, in seconds.


        :return: The ttl of this MigrationReplacement.
        :rtype: int
        """
        return self._ttl

    @ttl.setter
    def ttl(self, ttl):
        """
        Sets the ttl of this MigrationReplacement.
        The Time To Live of the replacement record, in seconds.


        :param ttl: The ttl of this MigrationReplacement.
        :type: int
        """
        self._ttl = ttl

    @property
    def rdata(self):
        """
        **[Required]** Gets the rdata of this MigrationReplacement.
        The record data of the replacement record, as whitespace-delimited tokens in
        type-specific presentation format.


        :return: The rdata of this MigrationReplacement.
        :rtype: str
        """
        return self._rdata

    @rdata.setter
    def rdata(self, rdata):
        """
        Sets the rdata of this MigrationReplacement.
        The record data of the replacement record, as whitespace-delimited tokens in
        type-specific presentation format.


        :param rdata: The rdata of this MigrationReplacement.
        :type: str
        """
        self._rdata = rdata

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2020, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.

from .data_asset import DataAsset
from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class DataAssetFromOracleDetails(DataAsset):
    """
    The Oracle data asset details.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new DataAssetFromOracleDetails object with values from keyword arguments. The default value of the :py:attr:`~oci.data_integration.models.DataAssetFromOracleDetails.model_type` attribute
        of this class is ``ORACLE_DATA_ASSET`` and it should not be changed.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param model_type:
            The value to assign to the model_type property of this DataAssetFromOracleDetails.
            Allowed values for this property are: "ORACLE_DATA_ASSET", "ORACLE_OBJECT_STORAGE_DATA_ASSET", "ORACLE_ATP_DATA_ASSET", "ORACLE_ADWC_DATA_ASSET"
        :type model_type: str

        :param key:
            The value to assign to the key property of this DataAssetFromOracleDetails.
        :type key: str

        :param model_version:
            The value to assign to the model_version property of this DataAssetFromOracleDetails.
        :type model_version: str

        :param name:
            The value to assign to the name property of this DataAssetFromOracleDetails.
        :type name: str

        :param description:
            The value to assign to the description property of this DataAssetFromOracleDetails.
        :type description: str

        :param object_status:
            The value to assign to the object_status property of this DataAssetFromOracleDetails.
        :type object_status: int

        :param identifier:
            The value to assign to the identifier property of this DataAssetFromOracleDetails.
        :type identifier: str

        :param external_key:
            The value to assign to the external_key property of this DataAssetFromOracleDetails.
        :type external_key: str

        :param asset_properties:
            The value to assign to the asset_properties property of this DataAssetFromOracleDetails.
        :type asset_properties: dict(str, str)

        :param native_type_system:
            The value to assign to the native_type_system property of this DataAssetFromOracleDetails.
        :type native_type_system: TypeSystem

        :param object_version:
            The value to assign to the object_version property of this DataAssetFromOracleDetails.
        :type object_version: int

        :param parent_ref:
            The value to assign to the parent_ref property of this DataAssetFromOracleDetails.
        :type parent_ref: ParentReference

        :param metadata:
            The value to assign to the metadata property of this DataAssetFromOracleDetails.
        :type metadata: ObjectMetadata

        :param key_map:
            The value to assign to the key_map property of this DataAssetFromOracleDetails.
        :type key_map: dict(str, str)

        :param host:
            The value to assign to the host property of this DataAssetFromOracleDetails.
        :type host: str

        :param port:
            The value to assign to the port property of this DataAssetFromOracleDetails.
        :type port: str

        :param service_name:
            The value to assign to the service_name property of this DataAssetFromOracleDetails.
        :type service_name: str

        :param driver_class:
            The value to assign to the driver_class property of this DataAssetFromOracleDetails.
        :type driver_class: str

        :param sid:
            The value to assign to the sid property of this DataAssetFromOracleDetails.
        :type sid: str

        :param credential_file_content:
            The value to assign to the credential_file_content property of this DataAssetFromOracleDetails.
        :type credential_file_content: str

        :param default_connection:
            The value to assign to the default_connection property of this DataAssetFromOracleDetails.
        :type default_connection: ConnectionFromOracleDetails

        """
        self.swagger_types = {
            'model_type': 'str',
            'key': 'str',
            'model_version': 'str',
            'name': 'str',
            'description': 'str',
            'object_status': 'int',
            'identifier': 'str',
            'external_key': 'str',
            'asset_properties': 'dict(str, str)',
            'native_type_system': 'TypeSystem',
            'object_version': 'int',
            'parent_ref': 'ParentReference',
            'metadata': 'ObjectMetadata',
            'key_map': 'dict(str, str)',
            'host': 'str',
            'port': 'str',
            'service_name': 'str',
            'driver_class': 'str',
            'sid': 'str',
            'credential_file_content': 'str',
            'default_connection': 'ConnectionFromOracleDetails'
        }

        self.attribute_map = {
            'model_type': 'modelType',
            'key': 'key',
            'model_version': 'modelVersion',
            'name': 'name',
            'description': 'description',
            'object_status': 'objectStatus',
            'identifier': 'identifier',
            'external_key': 'externalKey',
            'asset_properties': 'assetProperties',
            'native_type_system': 'nativeTypeSystem',
            'object_version': 'objectVersion',
            'parent_ref': 'parentRef',
            'metadata': 'metadata',
            'key_map': 'keyMap',
            'host': 'host',
            'port': 'port',
            'service_name': 'serviceName',
            'driver_class': 'driverClass',
            'sid': 'sid',
            'credential_file_content': 'credentialFileContent',
            'default_connection': 'defaultConnection'
        }

        self._model_type = None
        self._key = None
        self._model_version = None
        self._name = None
        self._description = None
        self._object_status = None
        self._identifier = None
        self._external_key = None
        self._asset_properties = None
        self._native_type_system = None
        self._object_version = None
        self._parent_ref = None
        self._metadata = None
        self._key_map = None
        self._host = None
        self._port = None
        self._service_name = None
        self._driver_class = None
        self._sid = None
        self._credential_file_content = None
        self._default_connection = None
        self._model_type = 'ORACLE_DATA_ASSET'

    @property
    def host(self):
        """
        Gets the host of this DataAssetFromOracleDetails.
        The host details for the data asset.


        :return: The host of this DataAssetFromOracleDetails.
        :rtype: str
        """
        return self._host

    @host.setter
    def host(self, host):
        """
        Sets the host of this DataAssetFromOracleDetails.
        The host details for the data asset.


        :param host: The host of this DataAssetFromOracleDetails.
        :type: str
        """
        self._host = host

    @property
    def port(self):
        """
        Gets the port of this DataAssetFromOracleDetails.
        The port details for the data asset.


        :return: The port of this DataAssetFromOracleDetails.
        :rtype: str
        """
        return self._port

    @port.setter
    def port(self, port):
        """
        Sets the port of this DataAssetFromOracleDetails.
        The port details for the data asset.


        :param port: The port of this DataAssetFromOracleDetails.
        :type: str
        """
        self._port = port

    @property
    def service_name(self):
        """
        Gets the service_name of this DataAssetFromOracleDetails.
        The service name for the data asset.


        :return: The service_name of this DataAssetFromOracleDetails.
        :rtype: str
        """
        return self._service_name

    @service_name.setter
    def service_name(self, service_name):
        """
        Sets the service_name of this DataAssetFromOracleDetails.
        The service name for the data asset.


        :param service_name: The service_name of this DataAssetFromOracleDetails.
        :type: str
        """
        self._service_name = service_name

    @property
    def driver_class(self):
        """
        Gets the driver_class of this DataAssetFromOracleDetails.
        The driver class for the data asset.


        :return: The driver_class of this DataAssetFromOracleDetails.
        :rtype: str
        """
        return self._driver_class

    @driver_class.setter
    def driver_class(self, driver_class):
        """
        Sets the driver_class of this DataAssetFromOracleDetails.
        The driver class for the data asset.


        :param driver_class: The driver_class of this DataAssetFromOracleDetails.
        :type: str
        """
        self._driver_class = driver_class

    @property
    def sid(self):
        """
        Gets the sid of this DataAssetFromOracleDetails.
        sid


        :return: The sid of this DataAssetFromOracleDetails.
        :rtype: str
        """
        return self._sid

    @sid.setter
    def sid(self, sid):
        """
        Sets the sid of this DataAssetFromOracleDetails.
        sid


        :param sid: The sid of this DataAssetFromOracleDetails.
        :type: str
        """
        self._sid = sid

    @property
    def credential_file_content(self):
        """
        Gets the credential_file_content of this DataAssetFromOracleDetails.
        The credential file content from a wallet for the data asset.


        :return: The credential_file_content of this DataAssetFromOracleDetails.
        :rtype: str
        """
        return self._credential_file_content

    @credential_file_content.setter
    def credential_file_content(self, credential_file_content):
        """
        Sets the credential_file_content of this DataAssetFromOracleDetails.
        The credential file content from a wallet for the data asset.


        :param credential_file_content: The credential_file_content of this DataAssetFromOracleDetails.
        :type: str
        """
        self._credential_file_content = credential_file_content

    @property
    def default_connection(self):
        """
        Gets the default_connection of this DataAssetFromOracleDetails.

        :return: The default_connection of this DataAssetFromOracleDetails.
        :rtype: ConnectionFromOracleDetails
        """
        return self._default_connection

    @default_connection.setter
    def default_connection(self, default_connection):
        """
        Sets the default_connection of this DataAssetFromOracleDetails.

        :param default_connection: The default_connection of this DataAssetFromOracleDetails.
        :type: ConnectionFromOracleDetails
        """
        self._default_connection = default_connection

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2020, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class ApiSpecificationRouteRequestPolicies(object):
    """
    Behavior applied to any requests received by the API on this route.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new ApiSpecificationRouteRequestPolicies object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param authorization:
            The value to assign to the authorization property of this ApiSpecificationRouteRequestPolicies.
        :type authorization: RouteAuthorizationPolicy

        :param cors:
            The value to assign to the cors property of this ApiSpecificationRouteRequestPolicies.
        :type cors: CorsPolicy

        :param header_transformations:
            The value to assign to the header_transformations property of this ApiSpecificationRouteRequestPolicies.
        :type header_transformations: HeaderTransformationPolicy

        :param query_parameter_transformations:
            The value to assign to the query_parameter_transformations property of this ApiSpecificationRouteRequestPolicies.
        :type query_parameter_transformations: QueryParameterTransformationPolicy

        """
        self.swagger_types = {
            'authorization': 'RouteAuthorizationPolicy',
            'cors': 'CorsPolicy',
            'header_transformations': 'HeaderTransformationPolicy',
            'query_parameter_transformations': 'QueryParameterTransformationPolicy'
        }

        self.attribute_map = {
            'authorization': 'authorization',
            'cors': 'cors',
            'header_transformations': 'headerTransformations',
            'query_parameter_transformations': 'queryParameterTransformations'
        }

        self._authorization = None
        self._cors = None
        self._header_transformations = None
        self._query_parameter_transformations = None

    @property
    def authorization(self):
        """
        Gets the authorization of this ApiSpecificationRouteRequestPolicies.

        :return: The authorization of this ApiSpecificationRouteRequestPolicies.
        :rtype: RouteAuthorizationPolicy
        """
        return self._authorization

    @authorization.setter
    def authorization(self, authorization):
        """
        Sets the authorization of this ApiSpecificationRouteRequestPolicies.

        :param authorization: The authorization of this ApiSpecificationRouteRequestPolicies.
        :type: RouteAuthorizationPolicy
        """
        self._authorization = authorization

    @property
    def cors(self):
        """
        Gets the cors of this ApiSpecificationRouteRequestPolicies.

        :return: The cors of this ApiSpecificationRouteRequestPolicies.
        :rtype: CorsPolicy
        """
        return self._cors

    @cors.setter
    def cors(self, cors):
        """
        Sets the cors of this ApiSpecificationRouteRequestPolicies.

        :param cors: The cors of this ApiSpecificationRouteRequestPolicies.
        :type: CorsPolicy
        """
        self._cors = cors

    @property
    def header_transformations(self):
        """
        Gets the header_transformations of this ApiSpecificationRouteRequestPolicies.

        :return: The header_transformations of this ApiSpecificationRouteRequestPolicies.
        :rtype: HeaderTransformationPolicy
        """
        return self._header_transformations

    @header_transformations.setter
    def header_transformations(self, header_transformations):
        """
        Sets the header_transformations of this ApiSpecificationRouteRequestPolicies.

        :param header_transformations: The header_transformations of this ApiSpecificationRouteRequestPolicies.
        :type: HeaderTransformationPolicy
        """
        self._header_transformations = header_transformations

    @property
    def query_parameter_transformations(self):
        """
        Gets the query_parameter_transformations of this ApiSpecificationRouteRequestPolicies.

        :return: The query_parameter_transformations of this ApiSpecificationRouteRequestPolicies.
        :rtype: QueryParameterTransformationPolicy
        """
        return self._query_parameter_transformations

    @query_parameter_transformations.setter
    def query_parameter_transformations(self, query_parameter_transformations):
        """
        Sets the query_parameter_transformations of this ApiSpecificationRouteRequestPolicies.

        :param query_parameter_transformations: The query_parameter_transformations of this ApiSpecificationRouteRequestPolicies.
        :type: QueryParameterTransformationPolicy
        """
        self._query_parameter_transformations = query_parameter_transformations

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2020, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class ResourceDiscoveryServiceSummary(object):
    """
    A service supported for use with Resource Discovery.
    """

    #: A constant which can be used with the discovery_scope property of a ResourceDiscoveryServiceSummary.
    #: This constant has a value of "TENANCY"
    DISCOVERY_SCOPE_TENANCY = "TENANCY"

    #: A constant which can be used with the discovery_scope property of a ResourceDiscoveryServiceSummary.
    #: This constant has a value of "COMPARTMENT"
    DISCOVERY_SCOPE_COMPARTMENT = "COMPARTMENT"

    def __init__(self, **kwargs):
        """
        Initializes a new ResourceDiscoveryServiceSummary object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param name:
            The value to assign to the name property of this ResourceDiscoveryServiceSummary.
        :type name: str

        :param discovery_scope:
            The value to assign to the discovery_scope property of this ResourceDiscoveryServiceSummary.
            Allowed values for this property are: "TENANCY", "COMPARTMENT", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type discovery_scope: str

        """
        self.swagger_types = {
            'name': 'str',
            'discovery_scope': 'str'
        }

        self.attribute_map = {
            'name': 'name',
            'discovery_scope': 'discoveryScope'
        }

        self._name = None
        self._discovery_scope = None

    @property
    def name(self):
        """
        Gets the name of this ResourceDiscoveryServiceSummary.
        A supported service. Example: `core`
        For reference on service names, see the `Terraform provider documentation`__.

        __ https://www.terraform.io/docs/providers/oci/guides/resource_discovery.html#services


        :return: The name of this ResourceDiscoveryServiceSummary.
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """
        Sets the name of this ResourceDiscoveryServiceSummary.
        A supported service. Example: `core`
        For reference on service names, see the `Terraform provider documentation`__.

        __ https://www.terraform.io/docs/providers/oci/guides/resource_discovery.html#services


        :param name: The name of this ResourceDiscoveryServiceSummary.
        :type: str
        """
        self._name = name

    @property
    def discovery_scope(self):
        """
        Gets the discovery_scope of this ResourceDiscoveryServiceSummary.
        The scope of the service as used with Resource Discovery.
        This property determines the type of compartment OCID required: root compartment (`TENANCY`) or not (`COMPARTMENT`).
        For example, `identity` is at the root compartment scope while `database` is at the compartment scope.

        Allowed values for this property are: "TENANCY", "COMPARTMENT", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The discovery_scope of this ResourceDiscoveryServiceSummary.
        :rtype: str
        """
        return self._discovery_scope

    @discovery_scope.setter
    def discovery_scope(self, discovery_scope):
        """
        Sets the discovery_scope of this ResourceDiscoveryServiceSummary.
        The scope of the service as used with Resource Discovery.
        This property determines the type of compartment OCID required: root compartment (`TENANCY`) or not (`COMPARTMENT`).
        For example, `identity` is at the root compartment scope while `database` is at the compartment scope.


        :param discovery_scope: The discovery_scope of this ResourceDiscoveryServiceSummary.
        :type: str
        """
        allowed_values = ["TENANCY", "COMPARTMENT"]
        if not value_allowed_none_or_none_sentinel(discovery_scope, allowed_values):
            discovery_scope = 'UNKNOWN_ENUM_VALUE'
        self._discovery_scope = discovery_scope

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2020, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class VolumeBackup(object):
    """
    A point-in-time copy of a volume that can then be used to create a new block volume
    or recover a block volume. For more information, see
    `Overview of Cloud Volume Storage`__.

    To use any of the API operations, you must be authorized in an IAM policy. If you're not authorized,
    talk to an administrator. If you're an administrator who needs to write policies to give users access, see
    `Getting Started with Policies`__.

    **Warning:** Oracle recommends that you avoid using any confidential information when you
    supply string values using the API.

    __ https://docs.cloud.oracle.com/Content/Block/Concepts/overview.htm
    __ https://docs.cloud.oracle.com/Content/Identity/Concepts/policygetstarted.htm
    """

    #: A constant which can be used with the lifecycle_state property of a VolumeBackup.
    #: This constant has a value of "CREATING"
    LIFECYCLE_STATE_CREATING = "CREATING"

    #: A constant which can be used with the lifecycle_state property of a VolumeBackup.
    #: This constant has a value of "AVAILABLE"
    LIFECYCLE_STATE_AVAILABLE = "AVAILABLE"

    #: A constant which can be used with the lifecycle_state property of a VolumeBackup.
    #: This constant has a value of "TERMINATING"
    LIFECYCLE_STATE_TERMINATING = "TERMINATING"

    #: A constant which can be used with the lifecycle_state property of a VolumeBackup.
    #: This constant has a value of "TERMINATED"
    LIFECYCLE_STATE_TERMINATED = "TERMINATED"

    #: A constant which can be used with the lifecycle_state property of a VolumeBackup.
    #: This constant has a value of "FAULTY"
    LIFECYCLE_STATE_FAULTY = "FAULTY"

    #: A constant which can be used with the lifecycle_state property of a VolumeBackup.
    #: This constant has a value of "REQUEST_RECEIVED"
    LIFECYCLE_STATE_REQUEST_RECEIVED = "REQUEST_RECEIVED"

    #: A constant which can be used with the source_type property of a VolumeBackup.
    #: This constant has a value of "MANUAL"
    SOURCE_TYPE_MANUAL = "MANUAL"

    #: A constant which can be used with the source_type property of a VolumeBackup.
    #: This constant has a value of "SCHEDULED"
    SOURCE_TYPE_SCHEDULED = "SCHEDULED"

    #: A constant which can be used with the type property of a VolumeBackup.
    #: This constant has a value of "FULL"
    TYPE_FULL = "FULL"

    #: A constant which can be used with the type property of a VolumeBackup.
    #: This constant has a value of "INCREMENTAL"
    TYPE_INCREMENTAL = "INCREMENTAL"

    def __init__(self, **kwargs):
        """
        Initializes a new VolumeBackup object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param compartment_id:
            The value to assign to the compartment_id property of this VolumeBackup.
        :type compartment_id: str

        :param defined_tags:
            The value to assign to the defined_tags property of this VolumeBackup.
        :type defined_tags: dict(str, dict(str, object))

        :param system_tags:
            The value to assign to the system_tags property of this VolumeBackup.
        :type system_tags: dict(str, dict(str, object))

        :param display_name:
            The value to assign to the display_name property of this VolumeBackup.
        :type display_name: str

        :param expiration_time:
            The value to assign to the expiration_time property of this VolumeBackup.
        :type expiration_time: datetime

        :param freeform_tags:
            The value to assign to the freeform_tags property of this VolumeBackup.
        :type freeform_tags: dict(str, str)

        :param id:
            The value to assign to the id property of this VolumeBackup.
        :type id: str

        :param kms_key_id:
            The value to assign to the kms_key_id property of this VolumeBackup.
        :type kms_key_id: str

        :param lifecycle_state:
            The value to assign to the lifecycle_state property of this VolumeBackup.
            Allowed values for this property are: "CREATING", "AVAILABLE", "TERMINATING", "TERMINATED", "FAULTY", "REQUEST_RECEIVED", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type lifecycle_state: str

        :param size_in_gbs:
            The value to assign to the size_in_gbs property of this VolumeBackup.
        :type size_in_gbs: int

        :param size_in_mbs:
            The value to assign to the size_in_mbs property of this VolumeBackup.
        :type size_in_mbs: int

        :param source_type:
            The value to assign to the source_type property of this VolumeBackup.
            Allowed values for this property are: "MANUAL", "SCHEDULED", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type source_type: str

        :param source_volume_backup_id:
            The value to assign to the source_volume_backup_id property of this VolumeBackup.
        :type source_volume_backup_id: str

        :param time_created:
            The value to assign to the time_created property of this VolumeBackup.
        :type time_created: datetime

        :param time_request_received:
            The value to assign to the time_request_received property of this VolumeBackup.
        :type time_request_received: datetime

        :param type:
            The value to assign to the type property of this VolumeBackup.
            Allowed values for this property are: "FULL", "INCREMENTAL", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type type: str

        :param unique_size_in_gbs:
            The value to assign to the unique_size_in_gbs property of this VolumeBackup.
        :type unique_size_in_gbs: int

        :param unique_size_in_mbs:
            The value to assign to the unique_size_in_mbs property of this VolumeBackup.
        :type unique_size_in_mbs: int

        :param volume_id:
            The value to assign to the volume_id property of this VolumeBackup.
        :type volume_id: str

        """
        self.swagger_types = {
            'compartment_id': 'str',
            'defined_tags': 'dict(str, dict(str, object))',
            'system_tags': 'dict(str, dict(str, object))',
            'display_name': 'str',
            'expiration_time': 'datetime',
            'freeform_tags': 'dict(str, str)',
            'id': 'str',
            'kms_key_id': 'str',
            'lifecycle_state': 'str',
            'size_in_gbs': 'int',
            'size_in_mbs': 'int',
            'source_type': 'str',
            'source_volume_backup_id': 'str',
            'time_created': 'datetime',
            'time_request_received': 'datetime',
            'type': 'str',
            'unique_size_in_gbs': 'int',
            'unique_size_in_mbs': 'int',
            'volume_id': 'str'
        }

        self.attribute_map = {
            'compartment_id': 'compartmentId',
            'defined_tags': 'definedTags',
            'system_tags': 'systemTags',
            'display_name': 'displayName',
            'expiration_time': 'expirationTime',
            'freeform_tags': 'freeformTags',
            'id': 'id',
            'kms_key_id': 'kmsKeyId',
            'lifecycle_state': 'lifecycleState',
            'size_in_gbs': 'sizeInGBs',
            'size_in_mbs': 'sizeInMBs',
            'source_type': 'sourceType',
            'source_volume_backup_id': 'sourceVolumeBackupId',
            'time_created': 'timeCreated',
            'time_request_received': 'timeRequestReceived',
            'type': 'type',
            'unique_size_in_gbs': 'uniqueSizeInGBs',
            'unique_size_in_mbs': 'uniqueSizeInMbs',
            'volume_id': 'volumeId'
        }

        self._compartment_id = None
        self._defined_tags = None
        self._system_tags = None
        self._display_name = None
        self._expiration_time = None
        self._freeform_tags = None
        self._id = None
        self._kms_key_id = None
        self._lifecycle_state = None
        self._size_in_gbs = None
        self._size_in_mbs = None
        self._source_type = None
        self._source_volume_backup_id = None
        self._time_created = None
        self._time_request_received = None
        self._type = None
        self._unique_size_in_gbs = None
        self._unique_size_in_mbs = None
        self._volume_id = None

    @property
    def compartment_id(self):
        """
        **[Required]** Gets the compartment_id of this VolumeBackup.
        The OCID of the compartment that contains the volume backup.


        :return: The compartment_id of this VolumeBackup.
        :rtype: str
        """
        return self._compartment_id

    @compartment_id.setter
    def compartment_id(self, compartment_id):
        """
        Sets the compartment_id of this VolumeBackup.
        The OCID of the compartment that contains the volume backup.


        :param compartment_id: The compartment_id of this VolumeBackup.
        :type: str
        """
        self._compartment_id = compartment_id

    @property
    def defined_tags(self):
        """
        Gets the defined_tags of this VolumeBackup.
        Defined tags for this resource. Each key is predefined and scoped to a
        namespace. For more information, see `Resource Tags`__.

        Example: `{\"Operations\": {\"CostCenter\": \"42\"}}`

        __ https://docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm


        :return: The defined_tags of this VolumeBackup.
        :rtype: dict(str, dict(str, object))
        """
        return self._defined_tags

    @defined_tags.setter
    def defined_tags(self, defined_tags):
        """
        Sets the defined_tags of this VolumeBackup.
        Defined tags for this resource. Each key is predefined and scoped to a
        namespace. For more information, see `Resource Tags`__.

        Example: `{\"Operations\": {\"CostCenter\": \"42\"}}`

        __ https://docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm


        :param defined_tags: The defined_tags of this VolumeBackup.
        :type: dict(str, dict(str, object))
        """
        self._defined_tags = defined_tags

    @property
    def system_tags(self):
        """
        Gets the system_tags of this VolumeBackup.
        System tags for this resource. Each key is predefined and scoped to a namespace.
        Example: `{\"foo-namespace\": {\"bar-key\": \"value\"}}`


        :return: The system_tags of this VolumeBackup.
        :rtype: dict(str, dict(str, object))
        """
        return self._system_tags

    @system_tags.setter
    def system_tags(self, system_tags):
        """
        Sets the system_tags of this VolumeBackup.
        System tags for this resource. Each key is predefined and scoped to a namespace.
        Example: `{\"foo-namespace\": {\"bar-key\": \"value\"}}`


        :param system_tags: The system_tags of this VolumeBackup.
        :type: dict(str, dict(str, object))
        """
        self._system_tags = system_tags

    @property
    def display_name(self):
        """
        **[Required]** Gets the display_name of this VolumeBackup.
        A user-friendly name for the volume backup. Does not have to be unique and it's changeable.
        Avoid entering confidential information.


        :return: The display_name of this VolumeBackup.
        :rtype: str
        """
        return self._display_name

    @display_name.setter
    def display_name(self, display_name):
        """
        Sets the display_name of this VolumeBackup.
        A user-friendly name for the volume backup. Does not have to be unique and it's changeable.
        Avoid entering confidential information.


        :param display_name: The display_name of this VolumeBackup.
        :type: str
        """
        self._display_name = display_name

    @property
    def expiration_time(self):
        """
        Gets the expiration_time of this VolumeBackup.
        The date and time the volume backup will expire and be automatically deleted.
        Format defined by `RFC3339`__. This parameter will always be present for backups that
        were created automatically by a scheduled-backup policy. For manually created backups,
        it will be absent, signifying that there is no expiration time and the backup will
        last forever until manually deleted.

        __ https://tools.ietf.org/html/rfc3339


        :return: The expiration_time of this VolumeBackup.
        :rtype: datetime
        """
        return self._expiration_time

    @expiration_time.setter
    def expiration_time(self, expiration_time):
        """
        Sets the expiration_time of this VolumeBackup.
        The date and time the volume backup will expire and be automatically deleted.
        Format defined by `RFC3339`__. This parameter will always be present for backups that
        were created automatically by a scheduled-backup policy. For manually created backups,
        it will be absent, signifying that there is no expiration time and the backup will
        last forever until manually deleted.

        __ https://tools.ietf.org/html/rfc3339


        :param expiration_time: The expiration_time of this VolumeBackup.
        :type: datetime
        """
        self._expiration_time = expiration_time

    @property
    def freeform_tags(self):
        """
        Gets the freeform_tags of this VolumeBackup.
        Free-form tags for this resource. Each tag is a simple key-value pair with no
        predefined name, type, or namespace. For more information, see `Resource Tags`__.

        Example: `{\"Department\": \"Finance\"}`

        __ https://docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm


        :return: The freeform_tags of this VolumeBackup.
        :rtype: dict(str, str)
        """
        return self._freeform_tags

    @freeform_tags.setter
    def freeform_tags(self, freeform_tags):
        """
        Sets the freeform_tags of this VolumeBackup.
        Free-form tags for this resource. Each tag is a simple key-value pair with no
        predefined name, type, or namespace. For more information, see `Resource Tags`__.

        Example: `{\"Department\": \"Finance\"}`

        __ https://docs.cloud.oracle.com/Content/General/Concepts/resourcetags.htm


        :param freeform_tags: The freeform_tags of this VolumeBackup.
        :type: dict(str, str)
        """
        self._freeform_tags = freeform_tags

    @property
    def id(self):
        """
        **[Required]** Gets the id of this VolumeBackup.
        The OCID of the volume backup.


        :return: The id of this VolumeBackup.
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """
        Sets the id of this VolumeBackup.
        The OCID of the volume backup.


        :param id: The id of this VolumeBackup.
        :type: str
        """
        self._id = id

    @property
    def kms_key_id(self):
        """
        Gets the kms_key_id of this VolumeBackup.
        The OCID of the Key Management key which is the master encryption key for the volume backup.
        For more information about the Key Management service and encryption keys, see
        `Overview of Key Management`__ and
        `Using Keys`__.

        __ https://docs.cloud.oracle.com/Content/KeyManagement/Concepts/keyoverview.htm
        __ https://docs.cloud.oracle.com/Content/KeyManagement/Tasks/usingkeys.htm


        :return: The kms_key_id of this VolumeBackup.
        :rtype: str
        """
        return self._kms_key_id

    @kms_key_id.setter
    def kms_key_id(self, kms_key_id):
        """
        Sets the kms_key_id of this VolumeBackup.
        The OCID of the Key Management key which is the master encryption key for the volume backup.
        For more information about the Key Management service and encryption keys, see
        `Overview of Key Management`__ and
        `Using Keys`__.

        __ https://docs.cloud.oracle.com/Content/KeyManagement/Concepts/keyoverview.htm
        __ https://docs.cloud.oracle.com/Content/KeyManagement/Tasks/usingkeys.htm


        :param kms_key_id: The kms_key_id of this VolumeBackup.
        :type: str
        """
        self._kms_key_id = kms_key_id

    @property
    def lifecycle_state(self):
        """
        **[Required]** Gets the lifecycle_state of this VolumeBackup.
        The current state of a volume backup.

        Allowed values for this property are: "CREATING", "AVAILABLE", "TERMINATING", "TERMINATED", "FAULTY", "REQUEST_RECEIVED", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The lifecycle_state of this VolumeBackup.
        :rtype: str
        """
        return self._lifecycle_state

    @lifecycle_state.setter
    def lifecycle_state(self, lifecycle_state):
        """
        Sets the lifecycle_state of this VolumeBackup.
        The current state of a volume backup.


        :param lifecycle_state: The lifecycle_state of this VolumeBackup.
        :type: str
        """
        allowed_values = ["CREATING", "AVAILABLE", "TERMINATING", "TERMINATED", "FAULTY", "REQUEST_RECEIVED"]
        if not value_allowed_none_or_none_sentinel(lifecycle_state, allowed_values):
            lifecycle_state = 'UNKNOWN_ENUM_VALUE'
        self._lifecycle_state = lifecycle_state

    @property
    def size_in_gbs(self):
        """
        Gets the size_in_gbs of this VolumeBackup.
        The size of the volume, in GBs.


        :return: The size_in_gbs of this VolumeBackup.
        :rtype: int
        """
        return self._size_in_gbs

    @size_in_gbs.setter
    def size_in_gbs(self, size_in_gbs):
        """
        Sets the size_in_gbs of this VolumeBackup.
        The size of the volume, in GBs.


        :param size_in_gbs: The size_in_gbs of this VolumeBackup.
        :type: int
        """
        self._size_in_gbs = size_in_gbs

    @property
    def size_in_mbs(self):
        """
        Gets the size_in_mbs of this VolumeBackup.
        The size of the volume in MBs. The value must be a multiple of 1024.
        This field is deprecated. Please use sizeInGBs.


        :return: The size_in_mbs of this VolumeBackup.
        :rtype: int
        """
        return self._size_in_mbs

    @size_in_mbs.setter
    def size_in_mbs(self, size_in_mbs):
        """
        Sets the size_in_mbs of this VolumeBackup.
        The size of the volume in MBs. The value must be a multiple of 1024.
        This field is deprecated. Please use sizeInGBs.


        :param size_in_mbs: The size_in_mbs of this VolumeBackup.
        :type: int
        """
        self._size_in_mbs = size_in_mbs

    @property
    def source_type(self):
        """
        Gets the source_type of this VolumeBackup.
        Specifies whether the backup was created manually, or via scheduled backup policy.

        Allowed values for this property are: "MANUAL", "SCHEDULED", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The source_type of this VolumeBackup.
        :rtype: str
        """
        return self._source_type

    @source_type.setter
    def source_type(self, source_type):
        """
        Sets the source_type of this VolumeBackup.
        Specifies whether the backup was created manually, or via scheduled backup policy.


        :param source_type: The source_type of this VolumeBackup.
        :type: str
        """
        allowed_values = ["MANUAL", "SCHEDULED"]
        if not value_allowed_none_or_none_sentinel(source_type, allowed_values):
            source_type = 'UNKNOWN_ENUM_VALUE'
        self._source_type = source_type

    @property
    def source_volume_backup_id(self):
        """
        Gets the source_volume_backup_id of this VolumeBackup.
        The OCID of the source volume backup.


        :return: The source_volume_backup_id of this VolumeBackup.
        :rtype: str
        """
        return self._source_volume_backup_id

    @source_volume_backup_id.setter
    def source_volume_backup_id(self, source_volume_backup_id):
        """
        Sets the source_volume_backup_id of this VolumeBackup.
        The OCID of the source volume backup.


        :param source_volume_backup_id: The source_volume_backup_id of this VolumeBackup.
        :type: str
        """
        self._source_volume_backup_id = source_volume_backup_id

    @property
    def time_created(self):
        """
        **[Required]** Gets the time_created of this VolumeBackup.
        The date and time the volume backup was created. This is the time the actual point-in-time image
        of the volume data was taken. Format defined by `RFC3339`__.

        __ https://tools.ietf.org/html/rfc3339


        :return: The time_created of this VolumeBackup.
        :rtype: datetime
        """
        return self._time_created

    @time_created.setter
    def time_created(self, time_created):
        """
        Sets the time_created of this VolumeBackup.
        The date and time the volume backup was created. This is the time the actual point-in-time image
        of the volume data was taken. Format defined by `RFC3339`__.

        __ https://tools.ietf.org/html/rfc3339


        :param time_created: The time_created of this VolumeBackup.
        :type: datetime
        """
        self._time_created = time_created

    @property
    def time_request_received(self):
        """
        Gets the time_request_received of this VolumeBackup.
        The date and time the request to create the volume backup was received. Format defined by [RFC3339]https://tools.ietf.org/html/rfc3339.


        :return: The time_request_received of this VolumeBackup.
        :rtype: datetime
        """
        return self._time_request_received

    @time_request_received.setter
    def time_request_received(self, time_request_received):
        """
        Sets the time_request_received of this VolumeBackup.
        The date and time the request to create the volume backup was received. Format defined by [RFC3339]https://tools.ietf.org/html/rfc3339.


        :param time_request_received: The time_request_received of this VolumeBackup.
        :type: datetime
        """
        self._time_request_received = time_request_received

    @property
    def type(self):
        """
        **[Required]** Gets the type of this VolumeBackup.
        The type of a volume backup.

        Allowed values for this property are: "FULL", "INCREMENTAL", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The type of this VolumeBackup.
        :rtype: str
        """
        return self._type

    @type.setter
    def type(self, type):
        """
        Sets the type of this VolumeBackup.
        The type of a volume backup.


        :param type: The type of this VolumeBackup.
        :type: str
        """
        allowed_values = ["FULL", "INCREMENTAL"]
        if not value_allowed_none_or_none_sentinel(type, allowed_values):
            type = 'UNKNOWN_ENUM_VALUE'
        self._type = type

    @property
    def unique_size_in_gbs(self):
        """
        Gets the unique_size_in_gbs of this VolumeBackup.
        The size used by the backup, in GBs. It is typically smaller than sizeInGBs, depending on the space
        consumed on the volume and whether the backup is full or incremental.


        :return: The unique_size_in_gbs of this VolumeBackup.
        :rtype: int
        """
        return self._unique_size_in_gbs

    @unique_size_in_gbs.setter
    def unique_size_in_gbs(self, unique_size_in_gbs):
        """
        Sets the unique_size_in_gbs of this VolumeBackup.
        The size used by the backup, in GBs. It is typically smaller than sizeInGBs, depending on the space
        consumed on the volume and whether the backup is full or incremental.


        :param unique_size_in_gbs: The unique_size_in_gbs of this VolumeBackup.
        :type: int
        """
        self._unique_size_in_gbs = unique_size_in_gbs

    @property
    def unique_size_in_mbs(self):
        """
        Gets the unique_size_in_mbs of this VolumeBackup.
        The size used by the backup, in MBs. It is typically smaller than sizeInMBs, depending on the space
        consumed on the volume and whether the backup is full or incremental.
        This field is deprecated. Please use uniqueSizeInGBs.


        :return: The unique_size_in_mbs of this VolumeBackup.
        :rtype: int
        """
        return self._unique_size_in_mbs

    @unique_size_in_mbs.setter
    def unique_size_in_mbs(self, unique_size_in_mbs):
        """
        Sets the unique_size_in_mbs of this VolumeBackup.
        The size used by the backup, in MBs. It is typically smaller than sizeInMBs, depending on the space
        consumed on the volume and whether the backup is full or incremental.
        This field is deprecated. Please use uniqueSizeInGBs.


        :param unique_size_in_mbs: The unique_size_in_mbs of this VolumeBackup.
        :type: int
        """
        self._unique_size_in_mbs = unique_size_in_mbs

    @property
    def volume_id(self):
        """
        Gets the volume_id of this VolumeBackup.
        The OCID of the volume.


        :return: The volume_id of this VolumeBackup.
        :rtype: str
        """
        return self._volume_id

    @volume_id.setter
    def volume_id(self, volume_id):
        """
        Sets the volume_id of this VolumeBackup.
        The OCID of the volume.


        :param volume_id: The volume_id of this VolumeBackup.
        :type: str
        """
        self._volume_id = volume_id

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2020, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class ResponderExecutionAggregation(object):
    """
    Provides the dimensions and their corresponding count value.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new ResponderExecutionAggregation object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param dimensions_map:
            The value to assign to the dimensions_map property of this ResponderExecutionAggregation.
        :type dimensions_map: dict(str, str)

        :param count:
            The value to assign to the count property of this ResponderExecutionAggregation.
        :type count: int

        """
        self.swagger_types = {
            'dimensions_map': 'dict(str, str)',
            'count': 'int'
        }

        self.attribute_map = {
            'dimensions_map': 'dimensionsMap',
            'count': 'count'
        }

        self._dimensions_map = None
        self._count = None

    @property
    def dimensions_map(self):
        """
        **[Required]** Gets the dimensions_map of this ResponderExecutionAggregation.
        The key-value pairs of dimensions and their names. The key corresponds to the Analytic Dimension(s) chosen, and the value corresponds to the value of the dimension from the data. E.g. if the Analytic Dimension chosen is \"RISK_LEVEL\", then the value will be like \"CRITICAL\". If the Analytic Dimensions chosen are \"RISK_LEVEL\" and \"RESOURCE_TYPE\", then the map will have two key-value pairs of form {\"RISK_LEVEL\" &#58; \"CRITICAL, \"RESOURCE_TYPE\" &#58; \"LOAD_BALANCER\"}


        :return: The dimensions_map of this ResponderExecutionAggregation.
        :rtype: dict(str, str)
        """
        return self._dimensions_map

    @dimensions_map.setter
    def dimensions_map(self, dimensions_map):
        """
        Sets the dimensions_map of this ResponderExecutionAggregation.
        The key-value pairs of dimensions and their names. The key corresponds to the Analytic Dimension(s) chosen, and the value corresponds to the value of the dimension from the data. E.g. if the Analytic Dimension chosen is \"RISK_LEVEL\", then the value will be like \"CRITICAL\". If the Analytic Dimensions chosen are \"RISK_LEVEL\" and \"RESOURCE_TYPE\", then the map will have two key-value pairs of form {\"RISK_LEVEL\" &#58; \"CRITICAL, \"RESOURCE_TYPE\" &#58; \"LOAD_BALANCER\"}


        :param dimensions_map: The dimensions_map of this ResponderExecutionAggregation.
        :type: dict(str, str)
        """
        self._dimensions_map = dimensions_map

    @property
    def count(self):
        """
        **[Required]** Gets the count of this ResponderExecutionAggregation.
        The number of occurences with given dimension(s)


        :return: The count of this ResponderExecutionAggregation.
        :rtype: int
        """
        return self._count

    @count.setter
    def count(self, count):
        """
        Sets the count of this ResponderExecutionAggregation.
        The number of occurences with given dimension(s)


        :param count: The count of this ResponderExecutionAggregation.
        :type: int
        """
        self._count = count

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2020, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.

from __future__ import absolute_import


from .blockstorage_client import BlockstorageClient
from .blockstorage_client_composite_operations import BlockstorageClientCompositeOperations
from .compute_client import ComputeClient
from .compute_client_composite_operations import ComputeClientCompositeOperations
from .compute_management_client import ComputeManagementClient
from .compute_management_client_composite_operations import ComputeManagementClientCompositeOperations
from .virtual_network_client import VirtualNetworkClient
from .virtual_network_client_composite_operations import VirtualNetworkClientCompositeOperations
from . import models

__all__ = ["BlockstorageClient", "BlockstorageClientCompositeOperations", "ComputeClient", "ComputeClientCompositeOperations", "ComputeManagementClient", "ComputeManagementClientCompositeOperations", "VirtualNetworkClient", "VirtualNetworkClientCompositeOperations", "models"]
